@@ -21,11 +21,15 @@ ascii alphabetic character, a-z, A-Z). e.g. "1", "10A", "1010b", "-1"
 
 See "ASTRAL RAF Sequence Maps":http://astral.stanford.edu/raf.html
 
-protein_letters_3to1 -- A mapping from the 3-letter amino acid codes found
-                        in PDB files to 1-letter codes.  The 3-letter codes
-                        include chemically modified residues.
+Dictionary `protein_letters_3to1` provides a mapping from the 3-letter amino
+acid codes found in PDB files to 1-letter codes.  The 3-letter codes include
+chemically modified residues.
 """
 
+from __future__ import print_function
+from Bio._py3k import basestring
+from Bio._py3k import _universal_read_mode
+
 from copy import copy
 
 from Bio.Data.SCOPData import protein_letters_3to1
@@ -51,21 +55,21 @@ class SeqMapIndex(dict):
     access of RAF records without having to load the entire file into memory.
 
     The index key is a concatenation of the  PDB ID and chain ID. e.g
-    "2drcA", "155c_". RAF uses an underscore to indicate blank
+    "2drcA", ``"155c_"``. RAF uses an underscore to indicate blank
     chain IDs.
     """
 
     def __init__(self, filename):
-        """
+        """Initialize the RAF file index.
+
         Arguments:
+         - filename  -- The file to index
 
-          filename  -- The file to index
         """
         dict.__init__(self)
         self.filename = filename
 
-        f = open(self.filename, "rU")
-        try:
+        with open(self.filename, _universal_read_mode) as f:
             position = 0
             while True:
                 line = f.readline()
@@ -73,29 +77,26 @@ class SeqMapIndex(dict):
                     break
                 key = line[0:5]
                 if key is not None:
-                    self[key]=position
+                    self[key] = position
                 position = f.tell()
-        finally:
-            f.close()
 
     def __getitem__(self, key):
-        """ Return an item from the indexed file. """
-        position = dict.__getitem__(self,key)
+        """Return an item from the indexed file."""
+        position = dict.__getitem__(self, key)
 
-        f = open(self.filename, "rU")
-        try:
+        with open(self.filename, _universal_read_mode) as f:
             f.seek(position)
             line = f.readline()
             record = SeqMap(line)
-        finally:
-            f.close()
         return record
 
     def getSeqMap(self, residues):
         """Get the sequence map for a collection of residues.
 
-        residues -- A Residues instance, or a string that can be converted into
-                    a Residues instance.
+        Arguments:
+         - residues -- A Residues instance, or a string that can be
+           converted into a Residues instance.
+
         """
         if isinstance(residues, basestring):
             residues = Residues(residues)
@@ -103,24 +104,24 @@ class SeqMapIndex(dict):
         pdbid = residues.pdbid
         frags = residues.fragments
         if not frags:
-            frags =(('_','',''),) # All residues of unnamed chain
+            frags = (('_', '', ''),)  # All residues of unnamed chain
 
         seqMap = None
         for frag in frags:
             chainid = frag[0]
-            if chainid=='' or chainid=='-' or chainid==' ' or chainid=='_':
+            if chainid in ['', '-', ' ', '_']:
                 chainid = '_'
             id = pdbid + chainid
 
             sm = self[id]
 
-            #Cut out fragment of interest
+            # Cut out fragment of interest
             start = 0
             end = len(sm.res)
             if frag[1]:
                 start = int(sm.index(frag[1], chainid))
             if frag[2]:
-                end = int(sm.index(frag[2], chainid)+1)
+                end = int(sm.index(frag[2], chainid)) + 1
 
             sm = sm[start:end]
 
@@ -139,18 +140,17 @@ class SeqMap(object):
     with index(), slice this SeqMap into fragments, and glue fragments back
     together with extend().
 
-    pdbid -- The PDB 4 character ID
+    Attributes:
+     - pdbid -- The PDB 4 character ID
+     - pdb_datestamp -- From the PDB file
+     - version -- The RAF format version. e.g. 0.01
+     - flags -- RAF flags. (See release notes for more information.)
+     - res -- A list of Res objects, one for each residue in this sequence map
 
-    pdb_datestamp -- From the PDB file
-
-    version -- The RAF format version. e.g. 0.01
-
-    flags -- RAF flags. (See release notes for more information.)
-
-    res -- A list of Res objects, one for each residue in this sequence map
     """
 
     def __init__(self, line=None):
+        """Initialize the class."""
         self.pdbid = ''
         self.pdb_datestamp = ''
         self.version = ''
@@ -160,31 +160,30 @@ class SeqMap(object):
             self._process(line)
 
     def _process(self, line):
-        """Parses a RAF record into a SeqMap object.
-        """
+        """Parse a RAF record into a SeqMap object."""
         header_len = 38
 
         line = line.rstrip()  # no trailing whitespace
 
-        if len(line)<header_len:
-            raise ValueError("Incomplete header: "+line)
+        if len(line) < header_len:
+            raise ValueError("Incomplete header: " + line)
 
         self.pdbid = line[0:4]
         chainid = line[4:5]
 
         self.version = line[6:10]
 
-        #Raf format versions 0.01 and 0.02 are identical for practical purposes
-        if(self.version != "0.01" and self.version !="0.02"):
-            raise ValueError("Incompatible RAF version: "+self.version)
+        # Raf format versions 0.01 and 0.02 are identical for practical purposes
+        if(self.version != "0.01" and self.version != "0.02"):
+            raise ValueError("Incompatible RAF version: " + self.version)
 
         self.pdb_datestamp = line[14:20]
         self.flags = line[21:27]
 
         for i in range(header_len, len(line), 7):
-            f = line[i : i+7]
-            if len(f)!=7:
-                raise ValueError("Corrupt Field: ("+f+")")
+            f = line[i:i + 7]
+            if len(f) != 7:
+                raise ValueError("Corrupt Field: (" + f + ")")
             r = Res()
             r.chainid = chainid
             r.resid = f[0:5].strip()
@@ -197,7 +196,7 @@ class SeqMap(object):
         for i in range(0, len(self.res)):
             if self.res[i].resid == resid and self.res[i].chainid == chainid:
                 return i
-        raise KeyError("No such residue "+chainid+resid)
+        raise KeyError("No such residue " + chainid + resid)
 
     def __getitem__(self, index):
         if not isinstance(index, slice):
@@ -249,25 +248,26 @@ class SeqMap(object):
         This is typically used to find the coordinates of a domain, or other
         residue subset.
 
-        pdb_handle -- A handle to the relevant PDB file.
+        Arguments:
+         - pdb_handle -- A handle to the relevant PDB file.
+         - out_handle -- All output is written to this file like object.
 
-        out_handle -- All output is written to this file like object.
         """
-        #This code should be refactored when (if?) biopython gets a PDB parser
+        # This code should be refactored when (if?) biopython gets a PDB parser
 
-        #The set of residues that I have to find records for.
+        # The set of residues that I have to find records for.
         resSet = {}
         for r in self.res:
-            if r.atom=='X':  # Unknown residue type
+            if r.atom == 'X':  # Unknown residue type
                 continue
             chainid = r.chainid
             if chainid == '_':
                 chainid = ' '
             resid = r.resid
-            resSet[(chainid,resid)] = r
+            resSet[(chainid, resid)] = r
 
         resFound = {}
-        for line in pdb_handle.xreadlines():
+        for line in pdb_handle:
             if line.startswith("ATOM  ") or line.startswith("HETATM"):
                 chainid = line[21:22]
                 resid = line[22:27].strip()
@@ -282,26 +282,27 @@ class SeqMap(object):
                             resFound[key] = res
 
         if len(resSet) != len(resFound):
-            #for k in resFound.keys():
+            # for k in resFound:
             #    del resSet[k]
-            #print resSet
-
-            raise RuntimeError('I could not find at least one ATOM or HETATM'
-                   +' record for each and every residue in this sequence map.')
+            # print(resSet)
+            raise RuntimeError("Could not find at least one ATOM or HETATM"
+                               " record for each and every residue in this"
+                               " sequence map.")
 
 
 class Res(object):
-    """ A single residue mapping from a RAF record.
+    """A single residue mapping from a RAF record.
 
-    chainid -- A single character chain ID.
+    Attributes:
+     - chainid -- A single character chain ID.
+     - resid   -- The residue ID.
+     - atom    -- amino acid one-letter code from ATOM records.
+     - seqres  -- amino acid one-letter code from SEQRES records.
 
-    resid   -- The residue ID.
-
-    atom    -- amino acid one-letter code from ATOM records.
-
-    seqres  -- amino acid one-letter code from SEQRES records.
     """
+
     def __init__(self):
+        """Initialize the class."""
         self.chainid = ''
         self.resid = ''
         self.atom = ''
@@ -309,12 +310,11 @@ class Res(object):
 
 
 def parse(handle):
-    """Iterates over a RAF file, returning a SeqMap object for each line
-    in the file.
+    """Iterate over RAF file, giving a SeqMap object for each line.
 
     Arguments:
+     - handle -- file-like object.
 
-        handle -- file-like object.
     """
     for line in handle:
         yield SeqMap(line)
