@@ -1,15 +1,20 @@
 # This code is part of the Biopython distribution and governed by its
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
-"""Tests for dealing with storage of biopython objects in a relational db.
-"""
+"""Dealing with storage of biopython objects in a BioSQL relational db."""
 from __future__ import print_function
 
 import os
 import platform
-import unittest
+import sys
 import tempfile
 import time
+import unittest
+
+try:
+    import configparser  # Python 3
+except ImportError:
+    import ConfigParser as configparser  # Python 2
 
 from Bio._py3k import StringIO
 from Bio._py3k import zip
@@ -23,7 +28,7 @@ from Bio import BiopythonWarning
 # local stuff
 from Bio import MissingExternalDependencyError
 from Bio.Seq import Seq, MutableSeq
-from Bio.SeqFeature import SeqFeature
+from Bio.SeqFeature import SeqFeature, UnknownPosition, ExactPosition
 from Bio import Alphabet
 from Bio import SeqIO
 from Bio.SeqRecord import SeqRecord
@@ -36,13 +41,30 @@ from seq_tests_common import compare_record, compare_records
 if __name__ == "__main__":
     raise RuntimeError("Call this via test_BioSQL_*.py not directly")
 
-global DBDRIVER, DBTYPE, DBHOST, DBUSER, DBPASSWD, TESTDB, DBSCHEMA, SQL_FILE
-global SYSTEM
+# Exporting these to the test_BioSQL_XXX.py files which import this file:
+# DBDRIVER, DBTYPE, DBHOST, DBUSER, DBPASSWD, TESTDB, DBSCHEMA, SQL_FILE, SYSTEM
 
 SYSTEM = platform.system()
 
 
+def load_biosql_ini(DBTYPE):
+    """Load the database settings from INI file."""
+    if not os.path.isfile("biosql.ini"):
+        raise MissingExternalDependencyError("BioSQL test configuration"
+                                             " file biosql.ini missing"
+                                             " (see biosql.ini.sample)")
+
+    config = configparser.ConfigParser()
+    config.read("biosql.ini")
+    DBHOST = config.get(DBTYPE, "dbhost")
+    DBUSER = config.get(DBTYPE, "dbuser")
+    DBPASSWD = config.get(DBTYPE, "dbpasswd")
+    TESTDB = config.get(DBTYPE, "testdb")
+    return DBHOST, DBUSER, DBPASSWD, TESTDB
+
+
 def temp_db_filename():
+    """Generate a temporary filename for SQLite database."""
     # In memory SQLite does not work with current test structure since the tests
     # expect databases to be retained between individual tests.
     # TESTDB = ':memory:'
@@ -57,6 +79,7 @@ def temp_db_filename():
 
 
 def check_config(dbdriver, dbtype, dbhost, dbuser, dbpasswd, testdb):
+    """Verify the database settings work for connecting."""
     global DBDRIVER, DBTYPE, DBHOST, DBUSER, DBPASSWD, TESTDB, DBSCHEMA
     global SYSTEM, SQL_FILE
     DBDRIVER = dbdriver
@@ -66,12 +89,16 @@ def check_config(dbdriver, dbtype, dbhost, dbuser, dbpasswd, testdb):
     DBPASSWD = dbpasswd
     TESTDB = testdb
 
+    if not DBDRIVER or not DBTYPE or not DBUSER:
+        # No point going any further...
+        raise MissingExternalDependencyError("Incomplete BioSQL test settings")
+
     # Check the database driver is installed:
     if SYSTEM == "Java":
         try:
             if DBDRIVER in ["MySQLdb"]:
                 import com.mysql.jdbc.Driver
-            elif DBDRIVER in ["psycopg2"]:
+            elif DBDRIVER in ["psycopg2", "pgdb"]:
                 import org.postgresql.Driver
         except ImportError:
             message = "Install the JDBC driver for %s to use BioSQL " % DBTYPE
@@ -103,62 +130,75 @@ def check_config(dbdriver, dbtype, dbhost, dbuser, dbpasswd, testdb):
         raise MissingExternalDependencyError(message)
 
 
-def _do_db_create():
-    """Do the actual work of database creation.
+def _do_db_cleanup():
+    """Cleanup everything from TESTDB.
 
     Relevant for MySQL and PostgreSQL.
     """
-    # first open a connection to create the database
-    server = BioSeqDatabase.open_database(driver=DBDRIVER, host=DBHOST,
-                                          user=DBUSER, passwd=DBPASSWD)
 
-    if DBDRIVER == "pgdb":
+    if DBDRIVER in ["psycopg2", "pgdb"]:
+        # first open a connection the database
+        # notice that postgres doesn't have createdb privileges, so
+        # the TESTDB must exist
+        server = BioSeqDatabase.open_database(driver=DBDRIVER, host=DBHOST,
+                                              user=DBUSER, passwd=DBPASSWD,
+                                              db=TESTDB)
+
         # The pgdb postgres driver does not support autocommit, so here we
         # commit the current transaction so that 'drop database' query will
         # be outside a transaction block
         server.adaptor.cursor.execute("COMMIT")
+        # drop anything in the database
+        # with Postgres, can get errors about database still being used.
+        # Wait briefly to be sure previous tests are done with it.
+        time.sleep(1)
+        # drop anything in the database
+        sql = r"DROP OWNED BY " + DBUSER
+        server.adaptor.cursor.execute(sql, ())
+        server.close()
     else:
-        # Auto-commit: postgresql cannot drop database in a transaction
+        # first open a connection to create the database
+        server = BioSeqDatabase.open_database(driver=DBDRIVER, host=DBHOST,
+                                              user=DBUSER, passwd=DBPASSWD)
+        # Auto-commit
         try:
             server.adaptor.autocommit()
         except AttributeError:
             pass
-
-    # drop anything in the database
-    try:
-        # with Postgres, can get errors about database still being used and
-        # not able to be dropped. Wait briefly to be sure previous tests are
-        # done with it.
-        time.sleep(1)
-        sql = r"DROP DATABASE " + TESTDB
-        server.adaptor.cursor.execute(sql, ())
-    except (server.module.OperationalError,
-            server.module.Error,
-            server.module.DatabaseError) as e:  # the database doesn't exist
-        pass
-    except (server.module.IntegrityError,
-            server.module.ProgrammingError) as e:  # ditto--perhaps
-        if str(e).find('database "%s" does not exist' % TESTDB) == -1:
-            server.close()
-            raise
-    # create a new database
-    sql = r"CREATE DATABASE " + TESTDB
-    server.adaptor.execute(sql, ())
-    server.close()
+        # drop the database
+        try:
+            sql = r"DROP DATABASE " + TESTDB
+            server.adaptor.cursor.execute(sql, ())
+        except (server.module.OperationalError,
+                server.module.Error,
+                server.module.DatabaseError) as e:  # the database doesn't exist
+            pass
+        except (server.module.IntegrityError,
+                server.module.ProgrammingError) as e:  # ditto--perhaps
+            if str(e).find('database "%s" does not exist' % TESTDB) == -1:
+                server.close()
+                raise
+        # create a new database
+        sql = r"CREATE DATABASE " + TESTDB
+        server.adaptor.execute(sql, ())
+        server.close()
 
 
 def create_database():
-    """Delete any existing BioSQL test database, then (re)create an empty BioSQL database."""
+    """Delete any existing BioSQL test DB, then (re)create an empty BioSQL DB.
+
+    Returns TESTDB name which will change for for SQLite.
+    """
     if DBDRIVER in ["sqlite3"]:
         global TESTDB
         if os.path.exists(TESTDB):
             try:
                 os.remove(TESTDB)
-            except:
+            except Exception:
                 time.sleep(1)
                 try:
                     os.remove(TESTDB)
-                except:
+                except Exception:
                     # Seen this with PyPy 2.1 (and older) on Windows -
                     # which suggests an open handle still exists?
                     print("Could not remove %r" % TESTDB)
@@ -167,7 +207,7 @@ def create_database():
         # (which might be happening under Windows...)
         TESTDB = temp_db_filename()
     else:
-        _do_db_create()
+        _do_db_cleanup()
 
     # now open a connection to load the database
     server = BioSeqDatabase.open_database(driver=DBDRIVER,
@@ -177,11 +217,13 @@ def create_database():
         server.load_database_sql(SQL_FILE)
         server.commit()
         server.close()
-    except:
+    except Exception:
         # Failed, but must close the handle...
         server.close()
         raise
 
+    return TESTDB
+
 
 def destroy_database():
     """Delete any temporary BioSQL sqlite3 database files."""
@@ -195,8 +237,7 @@ def load_database(gb_filename_or_handle):
 
     This is useful for running tests against a newly created database.
     """
-
-    create_database()
+    TESTDB = create_database()
     # now open a connection to load the database
     db_name = "biosql-test"
     server = BioSeqDatabase.open_database(driver=DBDRIVER,
@@ -213,14 +254,125 @@ def load_database(gb_filename_or_handle):
     return count
 
 
+def load_multi_database(gb_filename_or_handle, gb_filename_or_handle2):
+    """Load two GenBank files into a new BioSQL database as different subdatabases.
+
+    This is useful for running tests against a newly created database.
+    """
+    TESTDB = create_database()
+    # now open a connection to load the database
+    db_name = "biosql-test"
+    db_name2 = "biosql-test2"
+    server = BioSeqDatabase.open_database(driver=DBDRIVER,
+                                          user=DBUSER, passwd=DBPASSWD,
+                                          host=DBHOST, db=TESTDB)
+    db = server.new_database(db_name)
+
+    # get the GenBank file we are going to put into it
+    iterator = SeqIO.parse(gb_filename_or_handle, "gb")
+    count = db.load(iterator)
+
+    db = server.new_database(db_name2)
+
+    # get the GenBank file we are going to put into it
+    iterator = SeqIO.parse(gb_filename_or_handle2, "gb")
+    # finally put it in the database
+    count2 = db.load(iterator)
+    server.commit()
+
+    server.close()
+    return count + count2
+
+
+class MultiReadTest(unittest.TestCase):
+    """Test reading a database with multiple namespaces."""
+
+    loaded_db = 0
+
+    def setUp(self):
+        """Connect to and load up the database."""
+        load_multi_database("GenBank/cor6_6.gb", "GenBank/NC_000932.gb")
+
+        self.server = BioSeqDatabase.open_database(driver=DBDRIVER,
+                                                   user=DBUSER,
+                                                   passwd=DBPASSWD,
+                                                   host=DBHOST,
+                                                   db=TESTDB)
+
+        self.db = self.server["biosql-test"]
+        self.db2 = self.server['biosql-test2']
+
+    def tearDown(self):
+        self.server.close()
+        destroy_database()
+        del self.db
+        del self.db2
+        del self.server
+
+    def test_server(self):
+        """Check BioSeqDatabase methods."""
+        server = self.server
+        self.assertIn("biosql-test", server)
+        self.assertIn("biosql-test2", server)
+        self.assertEqual(2, len(server))
+        self.assertEqual(["biosql-test", 'biosql-test2'], list(server.keys()))
+        # Check we can delete the namespace...
+        del server["biosql-test"]
+        del server["biosql-test2"]
+        self.assertEqual(0, len(server))
+        try:
+            del server["non-existant-name"]
+            assert False, "Should have raised KeyError"
+        except KeyError:
+            pass
+
+    def test_get_db_items(self):
+        """Check list, keys, length etc."""
+        db = self.db
+        items = list(db.values())
+        keys = list(db)
+        length = len(items)
+        self.assertEqual(length, len(db))
+        self.assertEqual(length, len(list(db)))
+        self.assertEqual(length, len(list(db.items())))
+        self.assertEqual(length, len(list(db.keys())))
+        self.assertEqual(length, len(list(db.values())))
+        if sys.version_info[0] == 2:
+            # Check legacy methods for Python 2 as well:
+            self.assertEqual(length, len(list(db.iteritems())))
+            self.assertEqual(length, len(list(db.iterkeys())))
+            self.assertEqual(length, len(list(db.itervalues())))
+        for (k1, r1), (k2, r2) in zip(zip(keys, items), db.items()):
+            self.assertEqual(k1, k2)
+            self.assertEqual(r1.id, r2.id)
+        for k in keys:
+            del db[k]
+        self.assertEqual(0, len(db))
+        try:
+            del db["non-existant-name"]
+            assert False, "Should have raised KeyError"
+        except KeyError:
+            pass
+
+    def test_cross_retrieval_of_items(self):
+        """Test that valid ids can't be retrieved between namespaces."""
+        db = self.db
+        db2 = self.db2
+        for db2_id in db2.keys():
+            try:
+                rec = db[db2_id]
+                assert False, "Should have raised KeyError"
+            except KeyError:
+                pass
+
+
 class ReadTest(unittest.TestCase):
     """Test reading a database from an already built database."""
 
     loaded_db = 0
 
     def setUp(self):
-        """Connect to and load up the database.
-        """
+        """Connect to and load up the database."""
         load_database("GenBank/cor6_6.gb")
 
         self.server = BioSeqDatabase.open_database(driver=DBDRIVER,
@@ -238,9 +390,9 @@ class ReadTest(unittest.TestCase):
         del self.server
 
     def test_server(self):
-        """Check BioSeqDatabase methods"""
+        """Check BioSeqDatabase methods."""
         server = self.server
-        self.assertTrue("biosql-test" in server)
+        self.assertIn("biosql-test", server)
         self.assertEqual(1, len(server))
         self.assertEqual(["biosql-test"], list(server.keys()))
         # Check we can delete the namespace...
@@ -253,15 +405,15 @@ class ReadTest(unittest.TestCase):
             pass
 
     def test_get_db_items(self):
-        """Check list, keys, length etc"""
+        """Check list, keys, length etc."""
         db = self.db
         items = list(db.values())
         keys = list(db)
-        l = len(items)
-        self.assertEqual(l, len(db))
-        self.assertEqual(l, len(list(db.items())))
-        self.assertEqual(l, len(list(db)))
-        self.assertEqual(l, len(list(db.values())))
+        length = len(items)
+        self.assertEqual(length, len(db))
+        self.assertEqual(length, len(list(db.items())))
+        self.assertEqual(length, len(list(db)))
+        self.assertEqual(length, len(list(db.values())))
         for (k1, r1), (k2, r2) in zip(zip(keys, items), db.items()):
             self.assertEqual(k1, k2)
             self.assertEqual(r1.id, r2.id)
@@ -275,8 +427,7 @@ class ReadTest(unittest.TestCase):
             pass
 
     def test_lookup_items(self):
-        """Test retrieval of items using various ids.
-        """
+        """Test retrieval of items using various ids."""
         self.db.lookup(accession="X62281")
         try:
             self.db.lookup(accession="Not real")
@@ -303,8 +454,7 @@ class SeqInterfaceTest(unittest.TestCase):
     """Make sure the BioSQL objects implement the expected biopython interface."""
 
     def setUp(self):
-        """Load a database.
-        """
+        """Load a database."""
         load_database("GenBank/cor6_6.gb")
 
         self.server = BioSeqDatabase.open_database(driver=DBDRIVER,
@@ -321,13 +471,12 @@ class SeqInterfaceTest(unittest.TestCase):
         del self.server
 
     def test_seq_record(self):
-        """Make sure SeqRecords from BioSQL implement the right interface.
-        """
+        """Make sure SeqRecords from BioSQL implement the right interface."""
         test_record = self.item
         self.assertTrue(isinstance(test_record.seq, BioSeq.DBSeq))
         self.assertEqual(test_record.id, "X62281.1", test_record.id)
         self.assertEqual(test_record.name, "ATKIN2")
-        self.assertEqual(test_record.description, "A.thaliana kin2 gene.")
+        self.assertEqual(test_record.description, "A.thaliana kin2 gene")
         self.assertTrue(hasattr(test_record, 'annotations'))
         # XXX should do something with annotations once they are like
         # a dictionary
@@ -335,10 +484,14 @@ class SeqInterfaceTest(unittest.TestCase):
             self.assertTrue(isinstance(feature, SeqFeature))
         # shouldn't cause any errors!
         self.assertTrue(isinstance(str(test_record), basestring))
+        # Confirm can delete annotations etc to test these properties
+        del test_record.annotations
+        del test_record.dbxrefs
+        del test_record.features
+        del test_record.seq
 
     def test_seq(self):
-        """Make sure Seqs from BioSQL implement the right interface.
-        """
+        """Make sure Seqs from BioSQL implement the right interface."""
         test_seq = self.item.seq
         alphabet = test_seq.alphabet
         self.assertTrue(isinstance(alphabet, Alphabet.Alphabet))
@@ -348,6 +501,13 @@ class SeqInterfaceTest(unittest.TestCase):
         self.assertEqual(string_rep, str(test_seq))  # check __str__ too
         self.assertEqual(type(string_rep), type(""))
         self.assertEqual(len(test_seq), 880)
+        self.assertEqual(test_seq[879], "A")
+        self.assertEqual(test_seq[-1], "A")
+        self.assertEqual(test_seq[0], "A")
+        self.assertEqual(test_seq[-880], "A")
+        self.assertRaises(IndexError, test_seq.__getitem__, 880)
+        self.assertRaises(IndexError, test_seq.__getitem__, -881)
+        self.assertRaises(TypeError, test_seq.__getitem__, None)
 
     def test_convert(self):
         """Check can turn a DBSeq object into a Seq or MutableSeq."""
@@ -377,8 +537,7 @@ class SeqInterfaceTest(unittest.TestCase):
             self.assertEqual(str(test), str(other) + str(test_seq))
 
     def test_seq_slicing(self):
-        """Check that slices of sequences are retrieved properly.
-        """
+        """Check that slices of sequences are retrieved properly."""
         test_seq = self.item.seq
         new_seq = test_seq[:10]
         self.assertTrue(isinstance(new_seq, BioSeq.DBSeq))
@@ -394,17 +553,20 @@ class SeqInterfaceTest(unittest.TestCase):
         self.assertEqual(str(test_seq[-10:][5:]), "TTATA")
         self.assertEqual(str(test_seq[-10:][5:]), "TTATA")
 
+    def test_record_slicing(self):
+        """Check that slices of DBSeqRecord are retrieved properly."""
+        new_rec = self.item[400:]
+        self.assertTrue(isinstance(new_rec, SeqRecord))
+        self.assertEqual(len(new_rec), 480)
+        self.assertEqual(len(new_rec.features), 5)
+
     def test_seq_features(self):
-        """Check SeqFeatures of a sequence.
-        """
+        """Check SeqFeatures of a sequence."""
         test_features = self.item.features
         cds_feature = test_features[6]
         self.assertEqual(cds_feature.type, "CDS")
         self.assertEqual(str(cds_feature.location),
                          "join{[103:160](+), [319:390](+), [503:579](+)}")
-        for sub_feature in cds_feature._sub_features:
-            self.assertEqual(sub_feature.type, "CDS")
-            # self.assertEqual(sub_feature.location_operator, "join")
 
         try:
             self.assertEqual(cds_feature.qualifiers["gene"], ["kin2"])
@@ -414,11 +576,11 @@ class SeqInterfaceTest(unittest.TestCase):
             raise KeyError("Missing expected entries, have %s"
                            % repr(cds_feature.qualifiers))
 
-        self.assertTrue("db_xref" in cds_feature.qualifiers)
+        self.assertIn("db_xref", cds_feature.qualifiers)
         multi_ann = cds_feature.qualifiers["db_xref"]
         self.assertEqual(len(multi_ann), 2)
-        self.assertTrue("GI:16354" in multi_ann)
-        self.assertTrue("SWISS-PROT:P31169" in multi_ann)
+        self.assertIn("GI:16354", multi_ann)
+        self.assertIn("SWISS-PROT:P31169", multi_ann)
 
 
 class LoaderTest(unittest.TestCase):
@@ -426,7 +588,7 @@ class LoaderTest(unittest.TestCase):
 
     def setUp(self):
         # create TESTDB
-        create_database()
+        TESTDB = create_database()
 
         # load the database
         db_name = "biosql-test"
@@ -453,8 +615,7 @@ class LoaderTest(unittest.TestCase):
         del self.server
 
     def test_load_database(self):
-        """Load SeqRecord objects into a BioSQL database.
-        """
+        """Load SeqRecord objects into a BioSQL database."""
         self.db.load(self.iterator)
 
         # do some simple tests to make sure we actually loaded the right
@@ -475,12 +636,75 @@ class LoaderTest(unittest.TestCase):
                                     'M81224.1', 'X55053.1', 'X62281.1'])
 
 
+class DeleteTest(unittest.TestCase):
+    """Test proper deletion of entries from a database."""
+
+    loaded_db = 0
+
+    def setUp(self):
+        """Connect to and load up the database."""
+        load_database("GenBank/cor6_6.gb")
+
+        self.server = BioSeqDatabase.open_database(driver=DBDRIVER,
+                                                   user=DBUSER,
+                                                   passwd=DBPASSWD,
+                                                   host=DBHOST,
+                                                   db=TESTDB)
+
+        self.db = self.server["biosql-test"]
+
+    def tearDown(self):
+        self.server.close()
+        destroy_database()
+        del self.db
+        del self.server
+
+    def test_server(self):
+        """Check BioSeqDatabase methods."""
+        server = self.server
+        self.assertIn("biosql-test", server)
+        self.assertEqual(1, len(server))
+        self.assertEqual(["biosql-test"], list(server.keys()))
+        # Check we can delete the namespace...
+        del server["biosql-test"]
+        self.assertEqual(0, len(server))
+        try:
+            del server["non-existant-name"]
+            assert False, "Should have raised KeyError"
+        except KeyError:
+            pass
+
+    def test_del_db_items(self):
+        """Check all associated data is deleted from an item."""
+        db = self.db
+        items = list(db.values())
+        keys = list(db)
+        length = len(items)
+
+        for seq_id in keys:
+            sql = "SELECT seqfeature_id from seqfeature where bioentry_id = '%s'"
+            # get the original number of seqfeatures associated with the bioentry
+            seqfeatures = self.db.adaptor.execute_and_fetchall(sql % (seq_id))
+
+            del db[seq_id]
+            # check to see that the entry in the bioentry table is removed
+            self.assertEqual(seq_id in db, False)
+
+            # no need to check seqfeature presence if it had none to begin with
+            if len(seqfeatures):
+                rows_d = self.db.adaptor.execute_and_fetchall(sql % (seq_id))
+                # check to see that associated data is removed
+                self.assertEqual(len(rows_d), 0)
+
+        self.assertEqual(0, len(list(db.values())))
+
+
 class DupLoadTest(unittest.TestCase):
     """Check a few duplicate conditions fail."""
 
     def setUp(self):
         # drop any old database and create a new one:
-        create_database()
+        TESTDB = create_database()
         # connect to new database:
         self.server = BioSeqDatabase.open_database(driver=DBDRIVER,
                                                    user=DBUSER, passwd=DBPASSWD,
@@ -548,39 +772,48 @@ class DupLoadTest(unittest.TestCase):
 class ClosedLoopTest(unittest.TestCase):
     """Test file -> BioSQL -> file."""
 
-    # NOTE - For speed I don't bother to create a new database each time,
-    # simple a new unique namespace is used for each test.
+    @classmethod
+    def setUpClass(cls):
+        # NOTE - For speed I don't bother to create a new database each time,
+        # simply a new unique namespace is used for each test.
+        TESTDB = create_database()
 
     def test_NC_005816(self):
-        """GenBank file to BioSQL and back to a GenBank file, NC_005816."""
-        self.loop("GenBank/NC_005816.gb", "gb")
+        """From GenBank file to BioSQL and back to a GenBank file, NC_005816."""
+        with warnings.catch_warnings():
+            # BiopythonWarning: order location operators are not fully supported
+            warnings.simplefilter('ignore', BiopythonWarning)
+            self.loop("GenBank/NC_005816.gb", "gb")
 
     def test_NC_000932(self):
-        """GenBank file to BioSQL and back to a GenBank file, NC_000932."""
+        """From GenBank file to BioSQL and back to a GenBank file, NC_000932."""
         self.loop("GenBank/NC_000932.gb", "gb")
 
     def test_NT_019265(self):
-        """GenBank file to BioSQL and back to a GenBank file, NT_019265."""
+        """From GenBank file to BioSQL and back to a GenBank file, NT_019265."""
         self.loop("GenBank/NT_019265.gb", "gb")
 
     def test_protein_refseq2(self):
-        """GenBank file to BioSQL and back to a GenBank file, protein_refseq2."""
-        self.loop("GenBank/protein_refseq2.gb", "gb")
+        """From GenBank file to BioSQL and back to a GenBank file, protein_refseq2."""
+        with warnings.catch_warnings():
+            # BiopythonWarning: order location operators are not fully supported
+            warnings.simplefilter('ignore', BiopythonWarning)
+            self.loop("GenBank/protein_refseq2.gb", "gb")
 
     def test_no_ref(self):
-        """GenBank file to BioSQL and back to a GenBank file, noref."""
+        """From GenBank file to BioSQL and back to a GenBank file, noref."""
         self.loop("GenBank/noref.gb", "gb")
 
     def test_one_of(self):
-        """GenBank file to BioSQL and back to a GenBank file, one_of."""
+        """From GenBank file to BioSQL and back to a GenBank file, one_of."""
         self.loop("GenBank/one_of.gb", "gb")
 
     def test_cor6_6(self):
-        """GenBank file to BioSQL and back to a GenBank file, cor6_6."""
+        """From GenBank file to BioSQL and back to a GenBank file, cor6_6."""
         self.loop("GenBank/cor6_6.gb", "gb")
 
     def test_arab1(self):
-        """GenBank file to BioSQL and back to a GenBank file, arab1."""
+        """From GenBank file to BioSQL and back to a GenBank file, arab1."""
         self.loop("GenBank/arab1.gb", "gb")
 
     def loop(self, filename, format):
@@ -622,41 +855,47 @@ class TransferTest(unittest.TestCase):
     """Test file -> BioSQL, BioSQL -> BioSQL."""
 
     # NOTE - For speed I don't bother to create a new database each time,
-    # simple a new unique namespace is used for each test.
+    # simply a new unique namespace is used for each test.
 
     def setUp(self):
-        create_database()
+        TESTDB = create_database()
 
     def test_NC_005816(self):
-        """GenBank file to BioSQL, then again to a new namespace, NC_005816."""
-        self.trans("GenBank/NC_005816.gb", "gb")
+        """From GenBank file to BioSQL, then again to a new namespace, NC_005816."""
+        with warnings.catch_warnings():
+            # BiopythonWarning: order location operators are not fully supported
+            warnings.simplefilter('ignore', BiopythonWarning)
+            self.trans("GenBank/NC_005816.gb", "gb")
 
     def test_NC_000932(self):
-        """GenBank file to BioSQL, then again to a new namespace, NC_000932."""
+        """From GenBank file to BioSQL, then again to a new namespace, NC_000932."""
         self.trans("GenBank/NC_000932.gb", "gb")
 
     def test_NT_019265(self):
-        """GenBank file to BioSQL, then again to a new namespace, NT_019265."""
+        """From GenBank file to BioSQL, then again to a new namespace, NT_019265."""
         self.trans("GenBank/NT_019265.gb", "gb")
 
     def test_protein_refseq2(self):
-        """GenBank file to BioSQL, then again to a new namespace, protein_refseq2."""
-        self.trans("GenBank/protein_refseq2.gb", "gb")
+        """From GenBank file to BioSQL, then again to a new namespace, protein_refseq2."""
+        with warnings.catch_warnings():
+            # BiopythonWarning: order location operators are not fully supported
+            warnings.simplefilter('ignore', BiopythonWarning)
+            self.trans("GenBank/protein_refseq2.gb", "gb")
 
     def test_no_ref(self):
-        """GenBank file to BioSQL, then again to a new namespace, noref."""
+        """From GenBank file to BioSQL, then again to a new namespace, noref."""
         self.trans("GenBank/noref.gb", "gb")
 
     def test_one_of(self):
-        """GenBank file to BioSQL, then again to a new namespace, one_of."""
+        """From GenBank file to BioSQL, then again to a new namespace, one_of."""
         self.trans("GenBank/one_of.gb", "gb")
 
     def test_cor6_6(self):
-        """GenBank file to BioSQL, then again to a new namespace, cor6_6."""
+        """From GenBank file to BioSQL, then again to a new namespace, cor6_6."""
         self.trans("GenBank/cor6_6.gb", "gb")
 
     def test_arab1(self):
-        """GenBank file to BioSQL, then again to a new namespace, arab1."""
+        """From GenBank file to BioSQL, then again to a new namespace, arab1."""
         self.trans("GenBank/arab1.gb", "gb")
 
     def trans(self, filename, format):
@@ -744,25 +983,23 @@ class InDepthLoadTest(unittest.TestCase):
         raise Exception("Should have failed! Loaded %i records" % count)
 
     def test_record_loading(self):
-        """Make sure all records are correctly loaded.
-        """
+        """Make sure all records are correctly loaded."""
         test_record = self.db.lookup(accession="X55053")
         self.assertEqual(test_record.name, "ATCOR66M")
         self.assertEqual(test_record.id, "X55053.1")
-        self.assertEqual(test_record.description, "A.thaliana cor6.6 mRNA.")
+        self.assertEqual(test_record.description, "A.thaliana cor6.6 mRNA")
         self.assertTrue(isinstance(test_record.seq.alphabet, Alphabet.DNAAlphabet))
         self.assertEqual(str(test_record.seq[:10]), 'AACAAAACAC')
 
         test_record = self.db.lookup(accession="X62281")
         self.assertEqual(test_record.name, "ATKIN2")
         self.assertEqual(test_record.id, "X62281.1")
-        self.assertEqual(test_record.description, "A.thaliana kin2 gene.")
+        self.assertEqual(test_record.description, "A.thaliana kin2 gene")
         self.assertTrue(isinstance(test_record.seq.alphabet, Alphabet.DNAAlphabet))
         self.assertEqual(str(test_record.seq[:10]), 'ATTTGGCCTA')
 
     def test_seq_feature(self):
-        """In depth check that SeqFeatures are transmitted through the db.
-        """
+        """In depth check that SeqFeatures are transmitted through the db."""
         test_record = self.db.lookup(accession="AJ237582")
         features = test_record.features
         self.assertEqual(len(features), 7)
@@ -782,13 +1019,10 @@ class InDepthLoadTest(unittest.TestCase):
         test_feature = features[4]
         self.assertEqual(test_feature.type, "CDS")
         self.assertEqual(str(test_feature.location), "join{[0:48](+), [142:206](+)}")
-        self.assertEqual(len(test_feature._sub_features), 2)
-        self.assertEqual(str(test_feature._sub_features[0].location), "[0:48](+)")
-        self.assertEqual(test_feature._sub_features[0].type, "CDS")
-        # self.assertEqual(test_feature._sub_features[0].location_operator, "join")
-        self.assertEqual(str(test_feature._sub_features[1].location), "[142:206](+)")
-        self.assertEqual(test_feature._sub_features[1].type, "CDS")
-        # self.assertEqual(test_feature._sub_features[1].location_operator, "join")
+        self.assertEqual(len(test_feature.location.parts), 2)
+        self.assertEqual(str(test_feature.location.parts[0]), "[0:48](+)")
+        self.assertEqual(str(test_feature.location.parts[1]), "[142:206](+)")
+        self.assertEqual(test_feature.location.operator, "join")
         self.assertEqual(len(test_feature.qualifiers), 6)
         self.assertEqual(test_feature.qualifiers["gene"], ["csp14"])
         self.assertEqual(test_feature.qualifiers["codon_start"], ["2"])
@@ -804,8 +1038,8 @@ class InDepthLoadTest(unittest.TestCase):
         test_record = self.db.lookup(accession="AJ237582")
         test_feature = test_record.features[4]  # DNA, no complement
         self.assertEqual(test_feature.strand, 1)
-        for sub_feature in test_feature._sub_features:
-            self.assertEqual(sub_feature.strand, 1)
+        for loc in test_feature.location.parts:
+            self.assertEqual(loc.strand, 1)
 
         test_record = self.db.lookup(accession="X55053")
         test_feature = test_record.features[0]
@@ -821,6 +1055,11 @@ class AutoSeqIOTests(unittest.TestCase):
     server = None
     db = None
 
+    @classmethod
+    def setUpClass(cls):
+        # Create and reuse on database for all tests in this class
+        TESTDB = create_database()
+
     def setUp(self):
         """Connect to the database."""
         db_name = "biosql-test-seqio"
@@ -935,7 +1174,9 @@ class AutoSeqIOTests(unittest.TestCase):
             # BiopythonWarning: bond location operators are not fully supported
             warnings.simplefilter("ignore", BiopythonWarning)
             self.check('genbank', 'GenBank/dbsource_wrap.gb')
-        self.check('genbank', 'GenBank/NC_005816.gb')
+            # BiopythonWarning: order location operators are not fully
+            # supported
+            self.check('genbank', 'GenBank/NC_005816.gb')
         self.check('genbank', 'GenBank/gbvrl1_start.seq', 3)
         self.check('genbank', 'GFF/NC_001422.gbk')
         self.check('embl', 'EMBL/TRBG361.embl')
@@ -943,3 +1184,39 @@ class AutoSeqIOTests(unittest.TestCase):
         self.check('embl', 'EMBL/SC10H5.embl')
         self.check('embl', 'EMBL/U87107.embl')
         self.assertEqual(len(self.db), 66)
+
+
+class SwissProtUnknownPositionTest(unittest.TestCase):
+    """Handle SwissProt unknown position by setting value to null in database."""
+
+    def setUp(self):
+        # drop any old database and create a new one:
+        TESTDB = create_database()
+        # connect to new database:
+        self.server = BioSeqDatabase.open_database(driver=DBDRIVER,
+                                                   user=DBUSER, passwd=DBPASSWD,
+                                                   host=DBHOST, db=TESTDB)
+        # Create new namespace within new empty database:
+        self.db = self.server.new_database("biosql-test")
+
+    def tearDown(self):
+        self.server.rollback()
+        self.server.close()
+        destroy_database()
+        del self.db
+        del self.server
+
+    def test_ambiguous_location(self):
+        """Loaded uniprot-xml with ambiguous location in BioSQL."""
+        id = 'P97881'
+        seqiter = SeqIO.parse("SwissProt/%s.xml" % id, "uniprot-xml")
+        self.assertTrue(self.db.load(seqiter) == 1)
+
+        dbrecord = self.db.lookup(primary_id=id)
+        for feature in dbrecord.features:
+            if feature.type == 'signal peptide':
+                self.assertTrue(isinstance(feature.location.end, UnknownPosition))
+            elif feature.type == 'chain':
+                self.assertTrue(isinstance(feature.location.start, UnknownPosition))
+            else:
+                self.assertTrue(isinstance(feature.location.start, ExactPosition))
