@@ -28,28 +28,6 @@ class TestCluster(unittest.TestCase):
 
     module = 'Bio.Cluster'
 
-    def test_median_mean(self):
-        if TestCluster.module == 'Bio.Cluster':
-            from Bio.Cluster import mean, median
-        elif TestCluster.module == 'Pycluster':
-            from Pycluster import mean, median
-
-        data = numpy.array([ 34.3, 3, 2 ])
-        self.assertAlmostEqual(mean(data), 13.1, places=3)
-        self.assertAlmostEqual(median(data), 3.0, places=3)
-
-        data = [ 5, 10, 15, 20]
-        self.assertAlmostEqual(mean(data), 12.5, places=3)
-        self.assertAlmostEqual(median(data), 12.5, places=3)
-
-        data = [ 1, 2, 3, 5, 7, 11, 13, 17]
-        self.assertAlmostEqual(mean(data), 7.375, places=3)
-        self.assertAlmostEqual(median(data), 6.0, places=3)
-
-        data = [ 100, 19, 3, 1.5, 1.4, 1, 1, 1]
-        self.assertAlmostEqual(mean(data), 15.988, places=3)
-        self.assertAlmostEqual(median(data), 1.45, places=3)
-
     def test_matrix_parse(self):
         if TestCluster.module == 'Bio.Cluster':
             from Bio.Cluster import treecluster
@@ -57,41 +35,41 @@ class TestCluster(unittest.TestCase):
             from Pycluster import treecluster
 
         # Normal matrix, no errors
-        data1 = numpy.array([[ 1.1, 1.2 ],
-                             [ 1.4, 1.3 ],
-                             [ 1.1, 1.5 ],
-                             [ 2.0, 1.5 ],
-                             [ 1.7, 1.9 ],
-                             [ 1.7, 1.9 ],
-                             [ 5.7, 5.9 ],
-                             [ 5.7, 5.9 ],
-                             [ 3.1, 3.3 ],
-                             [ 5.4, 5.3 ],
-                             [ 5.1, 5.5 ],
-                             [ 5.0, 5.5 ],
-                             [ 5.1, 5.2 ]])
+        data1 = numpy.array([[1.1, 1.2],
+                             [1.4, 1.3],
+                             [1.1, 1.5],
+                             [2.0, 1.5],
+                             [1.7, 1.9],
+                             [1.7, 1.9],
+                             [5.7, 5.9],
+                             [5.7, 5.9],
+                             [3.1, 3.3],
+                             [5.4, 5.3],
+                             [5.1, 5.5],
+                             [5.0, 5.5],
+                             [5.1, 5.2]])
 
         # Another normal matrix, no errors; written as a list
-        data2 = [ [  1.1, 2.2, 3.3, 4.4, 5.5 ],
-                  [  3.1, 3.2, 1.3, 2.4, 1.5 ],
-                  [  4.1, 2.2, 0.3, 5.4, 0.5 ],
-                  [ 12.1, 2.0, 0.0, 5.0, 0.0 ]]
+        data2 = [[1.1, 2.2, 3.3, 4.4, 5.5],
+                 [3.1, 3.2, 1.3, 2.4, 1.5],
+                 [4.1, 2.2, 0.3, 5.4, 0.5],
+                 [12.1, 2.0, 0.0, 5.0, 0.0]]
 
         # Ragged matrix
-        data3 = [ [ 91.1, 92.2, 93.3, 94.4, 95.5],
-                  [ 93.1, 93.2, 91.3, 92.4 ],
-                  [ 94.1, 92.2, 90.3 ],
-                  [ 12.1, 92.0, 90.0, 95.0, 90.0 ]]
+        data3 = [[91.1, 92.2, 93.3, 94.4, 95.5],
+                 [93.1, 93.2, 91.3, 92.4],
+                 [94.1, 92.2, 90.3],
+                 [12.1, 92.0, 90.0, 95.0, 90.0]]
 
         # Matrix with bad cells
-        data4 = [  [ 7.1, 7.2, 7.3, 7.4, 7.5 ],
-                   [ 7.1, 7.2, 7.3, 7.4, 'snoopy' ],
-                   [ 7.1, 7.2, 7.3, None, None]]
+        data4 = [[7.1, 7.2, 7.3, 7.4, 7.5],
+                 [7.1, 7.2, 7.3, 7.4, 'snoopy'],
+                 [7.1, 7.2, 7.3, None, None]]
 
         # Matrix with a bad row
-        data5 = [  [ 23.1, 23.2, 23.3, 23.4, 23.5],
-                   None,
-                   [ 23.1, 23.0, 23.0, 23.0, 23.0]]
+        data5 = [[23.1, 23.2, 23.3, 23.4, 23.5],
+                 None,
+                 [23.1, 23.0, 23.0, 23.0, 23.0]]
 
         # Various references that don't point to matrices at all
         data6 = "snoopy"
@@ -101,21 +79,21 @@ class TestCluster(unittest.TestCase):
 
         try:
             treecluster(data1)
-        except:
+        except Exception:  # TODO - Which exceptions?
             self.fail("treecluster failed to accept matrix data1")
 
         try:
             treecluster(data2)
-        except:
+        except Exception:  # TODO - Which exceptions?
             self.fail("treecluster failed to accept matrix data2")
 
-        self.assertRaises(TypeError, lambda: treecluster(data3))
-        self.assertRaises(TypeError, lambda: treecluster(data4))
-        self.assertRaises(TypeError, lambda: treecluster(data5))
-        self.assertRaises(TypeError, lambda: treecluster(data6))
-        self.assertRaises(TypeError, lambda: treecluster(data7))
-        self.assertRaises(TypeError, lambda: treecluster(data8))
-        self.assertRaises(TypeError, lambda: treecluster(data9))
+        self.assertRaises(TypeError, treecluster, data3)
+        self.assertRaises(TypeError, treecluster, data4)
+        self.assertRaises(TypeError, treecluster, data5)
+        self.assertRaises(TypeError, treecluster, data6)
+        self.assertRaises(TypeError, treecluster, data7)
+        self.assertRaises(TypeError, treecluster, data8)
+        self.assertRaises(TypeError, treecluster, data9)
 
     def test_kcluster(self):
         if TestCluster.module == 'Bio.Cluster':
@@ -126,14 +104,14 @@ class TestCluster(unittest.TestCase):
         nclusters = 3
         # First data set
         weight = numpy.array([1, 1, 1, 1, 1])
-        data = numpy.array([[ 1.1, 2.2, 3.3, 4.4, 5.5],
-                            [ 3.1, 3.2, 1.3, 2.4, 1.5],
-                            [ 4.1, 2.2, 0.3, 5.4, 0.5],
+        data = numpy.array([[1.1, 2.2, 3.3, 4.4, 5.5],
+                            [3.1, 3.2, 1.3, 2.4, 1.5],
+                            [4.1, 2.2, 0.3, 5.4, 0.5],
                             [12.1, 2.0, 0.0, 5.0, 0.0]])
-        mask = numpy.array([[ 1, 1, 1, 1, 1],
-                             [ 1, 1, 1, 1, 1],
-                             [ 1, 1, 1, 1, 1],
-                             [ 1, 1, 1, 1, 1]], int)
+        mask = numpy.array([[1, 1, 1, 1, 1],
+                            [1, 1, 1, 1, 1],
+                            [1, 1, 1, 1, 1],
+                            [1, 1, 1, 1, 1]], int)
 
         # TODO - Use a context manager here once we drop Python 2.6
         # Method should be one letter:
@@ -161,32 +139,32 @@ class TestCluster(unittest.TestCase):
 
         # Second data set
         weight = numpy.array([1, 1])
-        data = numpy.array([[ 1.1, 1.2 ],
-                      [ 1.4, 1.3 ],
-                      [ 1.1, 1.5 ],
-                      [ 2.0, 1.5 ],
-                      [ 1.7, 1.9 ],
-                      [ 1.7, 1.9 ],
-                      [ 5.7, 5.9 ],
-                      [ 5.7, 5.9 ],
-                      [ 3.1, 3.3 ],
-                      [ 5.4, 5.3 ],
-                      [ 5.1, 5.5 ],
-                      [ 5.0, 5.5 ],
-                      [ 5.1, 5.2 ]])
-        mask = numpy.array([[ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ]], int)
+        data = numpy.array([[1.1, 1.2],
+                            [1.4, 1.3],
+                            [1.1, 1.5],
+                            [2.0, 1.5],
+                            [1.7, 1.9],
+                            [1.7, 1.9],
+                            [5.7, 5.9],
+                            [5.7, 5.9],
+                            [3.1, 3.3],
+                            [5.4, 5.3],
+                            [5.1, 5.5],
+                            [5.0, 5.5],
+                            [5.1, 5.2]])
+        mask = numpy.array([[1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1]], int)
 
         # TODO - Use a context manager here once we drop Python 2.6
         # Method should be one letter:
@@ -218,15 +196,15 @@ class TestCluster(unittest.TestCase):
             from Pycluster import clusterdistance
 
         # First data set
-        weight = numpy.array([ 1, 1, 1, 1, 1 ])
-        data = numpy.array([[  1.1, 2.2, 3.3, 4.4, 5.5 ],
-                            [  3.1, 3.2, 1.3, 2.4, 1.5 ],
-                            [  4.1, 2.2, 0.3, 5.4, 0.5 ],
-                            [ 12.1, 2.0, 0.0, 5.0, 0.0 ]])
-        mask = numpy.array([[ 1, 1, 1, 1, 1],
-                            [ 1, 1, 1, 1, 1],
-                            [ 1, 1, 1, 1, 1],
-                            [ 1, 1, 1, 1, 1]], int)
+        weight = numpy.array([1, 1, 1, 1, 1])
+        data = numpy.array([[1.1, 2.2, 3.3, 4.4, 5.5],
+                            [3.1, 3.2, 1.3, 2.4, 1.5],
+                            [4.1, 2.2, 0.3, 5.4, 0.5],
+                            [12.1, 2.0, 0.0, 5.0, 0.0]])
+        mask = numpy.array([[1, 1, 1, 1, 1],
+                            [1, 1, 1, 1, 1],
+                            [1, 1, 1, 1, 1],
+                            [1, 1, 1, 1, 1]], int)
 
         # Cluster assignments
         c1 = [0]
@@ -260,38 +238,38 @@ class TestCluster(unittest.TestCase):
         self.assertAlmostEqual(distance, 15.118, places=3)
 
         # Second data set
-        weight = numpy.array([ 1, 1 ])
-        data = numpy.array([[ 1.1, 1.2 ],
-                         [ 1.4, 1.3 ],
-                         [ 1.1, 1.5 ],
-                         [ 2.0, 1.5 ],
-                         [ 1.7, 1.9 ],
-                         [ 1.7, 1.9 ],
-                         [ 5.7, 5.9 ],
-                         [ 5.7, 5.9 ],
-                         [ 3.1, 3.3 ],
-                         [ 5.4, 5.3 ],
-                         [ 5.1, 5.5 ],
-                         [ 5.0, 5.5 ],
-                         [ 5.1, 5.2 ]])
-        mask = numpy.array([[ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ]], int)
+        weight = numpy.array([1, 1])
+        data = numpy.array([[1.1, 1.2],
+                            [1.4, 1.3],
+                            [1.1, 1.5],
+                            [2.0, 1.5],
+                            [1.7, 1.9],
+                            [1.7, 1.9],
+                            [5.7, 5.9],
+                            [5.7, 5.9],
+                            [3.1, 3.3],
+                            [5.4, 5.3],
+                            [5.1, 5.5],
+                            [5.0, 5.5],
+                            [5.1, 5.2]])
+        mask = numpy.array([[1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1]], int)
 
         # Cluster assignments
-        c1 = [ 0, 1, 2, 3 ]
-        c2 = [ 4, 5, 6, 7 ]
-        c3 = [ 8 ]
+        c1 = [0, 1, 2, 3]
+        c2 = [4, 5, 6, 7]
+        c3 = [8]
 
         # TODO - Use a context manager here once we drop Python 2.6
         # Method should be one letter:
@@ -328,15 +306,15 @@ class TestCluster(unittest.TestCase):
             from Pycluster import treecluster
 
         # First data set
-        weight1 = [ 1, 1, 1, 1, 1 ]
-        data1 = numpy.array([   [  1.1, 2.2, 3.3, 4.4, 5.5],
-                                [  3.1, 3.2, 1.3, 2.4, 1.5],
-                                [  4.1, 2.2, 0.3, 5.4, 0.5],
-                                [ 12.1, 2.0, 0.0, 5.0, 0.0]])
-        mask1 = numpy.array([[ 1, 1, 1, 1, 1],
-                             [ 1, 1, 1, 1, 1],
-                             [ 1, 1, 1, 1, 1],
-                             [ 1, 1, 1, 1, 1]], int)
+        weight1 = [1, 1, 1, 1, 1]
+        data1 = numpy.array([[1.1, 2.2, 3.3, 4.4, 5.5],
+                             [3.1, 3.2, 1.3, 2.4, 1.5],
+                             [4.1, 2.2, 0.3, 5.4, 0.5],
+                             [12.1, 2.0, 0.0, 5.0, 0.0]])
+        mask1 = numpy.array([[1, 1, 1, 1, 1],
+                             [1, 1, 1, 1, 1],
+                             [1, 1, 1, 1, 1],
+                             [1, 1, 1, 1, 1]], int)
 
         # TODO - Use a context manager here once we drop Python 2.6
         # Method should be one letter:
@@ -353,7 +331,7 @@ class TestCluster(unittest.TestCase):
         # Pairwise average-linkage clustering"
         tree = treecluster(data=data1, mask=mask1, weight=weight1,
                            transpose=0, method='a', dist='e')
-        self.assertEqual(len(tree), len(data1)-1)
+        self.assertEqual(len(tree), len(data1) - 1)
         self.assertEqual(tree[0].left, 2)
         self.assertEqual(tree[0].right, 1)
         self.assertAlmostEqual(tree[0].distance, 2.600, places=3)
@@ -367,7 +345,7 @@ class TestCluster(unittest.TestCase):
         # Pairwise single-linkage clustering
         tree = treecluster(data=data1, mask=mask1, weight=weight1,
                            transpose=0, method='s', dist='e')
-        self.assertEqual(len(tree), len(data1)-1)
+        self.assertEqual(len(tree), len(data1) - 1)
         self.assertEqual(tree[0].left, 1)
         self.assertEqual(tree[0].right, 2)
         self.assertAlmostEqual(tree[0].distance, 2.600, places=3)
@@ -381,7 +359,7 @@ class TestCluster(unittest.TestCase):
         # Pairwise centroid-linkage clustering
         tree = treecluster(data=data1, mask=mask1, weight=weight1,
                            transpose=0, method='c', dist='e')
-        self.assertEqual(len(tree), len(data1)-1)
+        self.assertEqual(len(tree), len(data1) - 1)
         self.assertEqual(tree[0].left, 1)
         self.assertEqual(tree[0].right, 2)
         self.assertAlmostEqual(tree[0].distance, 2.600, places=3)
@@ -395,7 +373,7 @@ class TestCluster(unittest.TestCase):
         # Pairwise maximum-linkage clustering
         tree = treecluster(data=data1, mask=mask1, weight=weight1,
                            transpose=0, method='m', dist='e')
-        self.assertEqual(len(tree), len(data1)-1)
+        self.assertEqual(len(tree), len(data1) - 1)
         self.assertEqual(tree[0].left, 2)
         self.assertEqual(tree[0].right, 1)
         self.assertAlmostEqual(tree[0].distance, 2.600, places=3)
@@ -407,39 +385,39 @@ class TestCluster(unittest.TestCase):
         self.assertAlmostEqual(tree[2].distance, 32.508, places=3)
 
         # Second data set
-        weight2 = [ 1, 1 ]
-        data2 = numpy.array([[ 0.8223, 0.9295 ],
-                             [ 1.4365, 1.3223 ],
-                             [ 1.1623, 1.5364 ],
-                             [ 2.1826, 1.1934 ],
-                             [ 1.7763, 1.9352 ],
-                             [ 1.7215, 1.9912 ],
-                             [ 2.1812, 5.9935 ],
-                             [ 5.3290, 5.9452 ],
-                             [ 3.1491, 3.3454 ],
-                             [ 5.1923, 5.3156 ],
-                             [ 4.7735, 5.4012 ],
-                             [ 5.1297, 5.5645 ],
-                             [ 5.3934, 5.1823 ]])
-        mask2 = numpy.array([[ 1, 1 ],
-                             [ 1, 1 ],
-                             [ 1, 1 ],
-                             [ 1, 1 ],
-                             [ 1, 1 ],
-                             [ 1, 1 ],
-                             [ 1, 1 ],
-                             [ 1, 1 ],
-                             [ 1, 1 ],
-                             [ 1, 1 ],
-                             [ 1, 1 ],
-                             [ 1, 1 ],
-                             [ 1, 1 ]], int)
+        weight2 = [1, 1]
+        data2 = numpy.array([[0.8223, 0.9295],
+                             [1.4365, 1.3223],
+                             [1.1623, 1.5364],
+                             [2.1826, 1.1934],
+                             [1.7763, 1.9352],
+                             [1.7215, 1.9912],
+                             [2.1812, 5.9935],
+                             [5.3290, 5.9452],
+                             [3.1491, 3.3454],
+                             [5.1923, 5.3156],
+                             [4.7735, 5.4012],
+                             [5.1297, 5.5645],
+                             [5.3934, 5.1823]])
+        mask2 = numpy.array([[1, 1],
+                             [1, 1],
+                             [1, 1],
+                             [1, 1],
+                             [1, 1],
+                             [1, 1],
+                             [1, 1],
+                             [1, 1],
+                             [1, 1],
+                             [1, 1],
+                             [1, 1],
+                             [1, 1],
+                             [1, 1]], int)
 
         # Test second data set
         # Pairwise average-linkage clustering
         tree = treecluster(data=data2, mask=mask2, weight=weight2,
                            transpose=0, method='a', dist='e')
-        self.assertEqual(len(tree), len(data2)-1)
+        self.assertEqual(len(tree), len(data2) - 1)
         self.assertEqual(tree[0].left, 5)
         self.assertEqual(tree[0].right, 4)
         self.assertAlmostEqual(tree[0].distance, 0.003, places=3)
@@ -480,7 +458,7 @@ class TestCluster(unittest.TestCase):
         # Pairwise single-linkage clustering
         tree = treecluster(data=data2, mask=mask2, weight=weight2,
                            transpose=0, method='s', dist='e')
-        self.assertEqual(len(tree), len(data2)-1)
+        self.assertEqual(len(tree), len(data2) - 1)
         self.assertEqual(tree[0].left, 4)
         self.assertEqual(tree[0].right, 5)
         self.assertAlmostEqual(tree[0].distance, 0.003, places=3)
@@ -521,7 +499,7 @@ class TestCluster(unittest.TestCase):
         # Pairwise centroid-linkage clustering
         tree = treecluster(data=data2, mask=mask2, weight=weight2,
                            transpose=0, method='c', dist='e')
-        self.assertEqual(len(tree), len(data2)-1)
+        self.assertEqual(len(tree), len(data2) - 1)
         self.assertEqual(tree[0].left, 4)
         self.assertEqual(tree[0].right, 5)
         self.assertAlmostEqual(tree[0].distance, 0.003, places=3)
@@ -562,7 +540,7 @@ class TestCluster(unittest.TestCase):
         # Pairwise maximum-linkage clustering
         tree = treecluster(data=data2, mask=mask2, weight=weight2,
                            transpose=0, method='m', dist='e')
-        self.assertEqual(len(tree), len(data2)-1)
+        self.assertEqual(len(tree), len(data2) - 1)
         self.assertEqual(tree[0].left, 5)
         self.assertEqual(tree[0].right, 4)
         self.assertAlmostEqual(tree[0].distance, 0.003, places=3)
@@ -607,15 +585,15 @@ class TestCluster(unittest.TestCase):
             from Pycluster import somcluster
 
         # First data set
-        weight = [ 1, 1, 1, 1, 1 ]
-        data = numpy.array([[  1.1, 2.2, 3.3, 4.4, 5.5],
-                            [  3.1, 3.2, 1.3, 2.4, 1.5],
-                            [  4.1, 2.2, 0.3, 5.4, 0.5],
-                            [ 12.1, 2.0, 0.0, 5.0, 0.0]])
-        mask = numpy.array([[ 1, 1, 1, 1, 1],
-                            [ 1, 1, 1, 1, 1],
-                            [ 1, 1, 1, 1, 1],
-                            [ 1, 1, 1, 1, 1]], int)
+        weight = [1, 1, 1, 1, 1]
+        data = numpy.array([[1.1, 2.2, 3.3, 4.4, 5.5],
+                            [3.1, 3.2, 1.3, 2.4, 1.5],
+                            [4.1, 2.2, 0.3, 5.4, 0.5],
+                            [12.1, 2.0, 0.0, 5.0, 0.0]])
+        mask = numpy.array([[1, 1, 1, 1, 1],
+                            [1, 1, 1, 1, 1],
+                            [1, 1, 1, 1, 1],
+                            [1, 1, 1, 1, 1]], int)
 
         # TODO - Use a context manager here once we drop Python 2.6
         # Distance should be one letter:
@@ -631,33 +609,33 @@ class TestCluster(unittest.TestCase):
         self.assertEqual(len(clusterid[0]), 2)
 
         # Second data set
-        weight = [ 1, 1 ]
-        data = numpy.array([[ 1.1, 1.2 ],
-                            [ 1.4, 1.3 ],
-                            [ 1.1, 1.5 ],
-                            [ 2.0, 1.5 ],
-                            [ 1.7, 1.9 ],
-                            [ 1.7, 1.9 ],
-                            [ 5.7, 5.9 ],
-                            [ 5.7, 5.9 ],
-                            [ 3.1, 3.3 ],
-                            [ 5.4, 5.3 ],
-                            [ 5.1, 5.5 ],
-                            [ 5.0, 5.5 ],
-                            [ 5.1, 5.2 ]])
-        mask = numpy.array([[ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ],
-                            [ 1, 1 ]], int)
+        weight = [1, 1]
+        data = numpy.array([[1.1, 1.2],
+                            [1.4, 1.3],
+                            [1.1, 1.5],
+                            [2.0, 1.5],
+                            [1.7, 1.9],
+                            [1.7, 1.9],
+                            [5.7, 5.9],
+                            [5.7, 5.9],
+                            [3.1, 3.3],
+                            [5.4, 5.3],
+                            [5.1, 5.5],
+                            [5.0, 5.5],
+                            [5.1, 5.2]])
+        mask = numpy.array([[1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1],
+                            [1, 1]], int)
 
         clusterid, celldata = somcluster(data=data, mask=mask, weight=weight,
                                          transpose=0, nxgrid=10, nygrid=10,
@@ -753,20 +731,20 @@ class TestCluster(unittest.TestCase):
         elif TestCluster.module == 'Pycluster':
             from Pycluster import pca
 
-        data = numpy.array([[ 3.1, 1.2 ],
-                            [ 1.4, 1.3 ],
-                            [ 1.1, 1.5 ],
-                            [ 2.0, 1.5 ],
-                            [ 1.7, 1.9 ],
-                            [ 1.7, 1.9 ],
-                            [ 5.7, 5.9 ],
-                            [ 5.7, 5.9 ],
-                            [ 3.1, 3.3 ],
-                            [ 5.4, 5.3 ],
-                            [ 5.1, 5.5 ],
-                            [ 5.0, 5.5 ],
-                            [ 5.1, 5.2 ],
-                           ])
+        data = numpy.array([[3.1, 1.2],
+                            [1.4, 1.3],
+                            [1.1, 1.5],
+                            [2.0, 1.5],
+                            [1.7, 1.9],
+                            [1.7, 1.9],
+                            [5.7, 5.9],
+                            [5.7, 5.9],
+                            [3.1, 3.3],
+                            [5.4, 5.3],
+                            [5.1, 5.5],
+                            [5.0, 5.5],
+                            [5.1, 5.2],
+                            ])
 
         mean, coordinates, pc, eigenvalues = pca(data)
         self.assertAlmostEqual(mean[0], 3.5461538461538464)
@@ -804,10 +782,10 @@ class TestCluster(unittest.TestCase):
         self.assertAlmostEqual(eigenvalues[0], 9.3110471246032844)
         self.assertAlmostEqual(eigenvalues[1], 1.4437456297481428)
 
-        data = numpy.array([[ 2.3, 4.5, 1.2, 6.7, 5.3, 7.1],
-                            [ 1.3, 6.5, 2.2, 5.7, 6.2, 9.1],
-                            [ 3.2, 7.2, 3.2, 7.4, 7.3, 8.9],
-                            [ 4.2, 5.2, 9.2, 4.4, 6.3, 7.2]])
+        data = numpy.array([[2.3, 4.5, 1.2, 6.7, 5.3, 7.1],
+                            [1.3, 6.5, 2.2, 5.7, 6.2, 9.1],
+                            [3.2, 7.2, 3.2, 7.4, 7.3, 8.9],
+                            [4.2, 5.2, 9.2, 4.4, 6.3, 7.2]])
         mean, coordinates, pc, eigenvalues = pca(data)
         self.assertAlmostEqual(mean[0], 2.7500)
         self.assertAlmostEqual(mean[1], 5.8500)
@@ -852,6 +830,7 @@ class TestCluster(unittest.TestCase):
         self.assertAlmostEqual(eigenvalues[2], 1.8775592718563467)
         self.assertAlmostEqual(eigenvalues[3], 0.0)
 
+
 if __name__ == "__main__":
     TestCluster.module = 'Bio.Cluster'
     runner = unittest.TextTestRunner(verbosity=2)
