@@ -9,10 +9,14 @@ from Bio.Seq import MutableSeq
 from Bio.Alphabet import SingleLetterAlphabet
 
 # local stuff
-from Bio.GA.Organism import Organism
-from Bio.GA.Mutation.General import SafeFitnessMutation
-from Bio.GA.Mutation.Simple import ConversionMutation
-from Bio.GA.Mutation.Simple import SinglePositionMutation
+import warnings
+from Bio import BiopythonDeprecationWarning
+with warnings.catch_warnings():
+    warnings.simplefilter('ignore', BiopythonDeprecationWarning)
+    from Bio.GA.Organism import Organism
+    from Bio.GA.Mutation.General import SafeFitnessMutation
+    from Bio.GA.Mutation.Simple import ConversionMutation
+    from Bio.GA.Mutation.Simple import SinglePositionMutation
 
 
 class TestAlphabet(SingleLetterAlphabet):
@@ -28,7 +32,7 @@ def test_fitness(genome):
     return int(str(seq_genome))
 
 
-class MutationHelper:
+class MutationHelper(object):
     """Mixin class which provides useful functions for testing mutations.
     """
     num_trials = 1000
@@ -54,7 +58,7 @@ class MutationHelper:
 
         percent_mutants = float(num_mutations) / float(self.num_trials)
         assert percent_mutants > expected_percent, \
-               "Did not recieve an acceptable number of mutations."
+               "Did not receive an acceptable number of mutations."
 
     def _never_mutate(self, mutator):
         """Test that a mutator does not cause unexpected mutations.
@@ -119,10 +123,11 @@ class SinglePositionTest(unittest.TestCase, MutationHelper):
         self._never_mutate(mutator)
 
 
-class TestMutator:
-    """Provide basic mutator ability.
-    """
+class TestMutator(object):
+    """Provide basic mutator ability."""
+
     def __init__(self):
+        """Initialize."""
         self.type = "lower"
 
     def mutate(self, org):
@@ -195,6 +200,7 @@ class SafeFitnessTest(unittest.TestCase):
         assert (new_org.fitness > self.org.fitness), \
                 "Did not get new organism under higher fitness conditions."
 
+
 if __name__ == "__main__":
     runner = unittest.TextTestRunner(verbosity=2)
     unittest.main(testRunner=runner)
