@@ -1,5 +1,5 @@
-#!/usr/bin/env python
-
+# Copyright 2001 Brad Chapman.  All rights reserved.
+#
 # This code is part of the Biopython distribution and governed by its
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
@@ -9,22 +9,26 @@
 This exercises the Motif, Schema and Signature methods of representing
 genes, as well as generic Pattern methods.
 """
-# standard library
+
 from __future__ import print_function
 
 import os
 import unittest
+import warnings
 
-# Biopython
 from Bio import SeqIO
 from Bio.Seq import Seq
 from Bio.Alphabet import IUPAC
+from Bio.SeqRecord import SeqRecord
 
-# stuff we are testing
-from Bio.NeuralNetwork.Gene import Schema
-from Bio.NeuralNetwork.Gene import Motif
-from Bio.NeuralNetwork.Gene import Signature
-from Bio.NeuralNetwork.Gene import Pattern
+from Bio import BiopythonDeprecationWarning
+with warnings.catch_warnings():
+    warnings.simplefilter('ignore', BiopythonDeprecationWarning)
+    # stuff we are testing
+    from Bio.NeuralNetwork.Gene import Schema
+    from Bio.NeuralNetwork.Gene import Motif
+    from Bio.NeuralNetwork.Gene import Signature
+    from Bio.NeuralNetwork.Gene import Pattern
 
 VERBOSE = 0
 
@@ -32,34 +36,30 @@ VERBOSE = 0
 # --- Tests for Pattern
 
 class PatternIOTest(unittest.TestCase):
-    """Tests for reading and writing patterns to a file.
-    """
+    """Tests for reading and writing patterns to a file."""
     def setUp(self):
         self.alphabet = IUPAC.ambiguous_dna
         self.test_file = os.path.join("NeuralNetwork", "patternio.txt")
-        #Remove any existing copy of the output file,
+        # Remove any existing copy of the output file,
         if os.path.isfile(self.test_file):
             os.remove(self.test_file)
         self.pattern_io = Pattern.PatternIO(self.alphabet)
 
     def tearDown(self):
-        #Clean up by removing our output file,
+        # Clean up by removing our output file,
         if os.path.isfile(self.test_file):
             os.remove(self.test_file)
 
     def test_motif(self):
-        """Reading and writing motifs to a file
-        """
+        """Reading and writing motifs to a file."""
         # write to a file
         motifs = ["GAC", "AAA", "TTT", "GGG"]
-        output_handle = open(self.test_file, "w")
-        self.pattern_io.write(motifs, output_handle)
-        output_handle.close()
+        with open(self.test_file, "w") as output_handle:
+            self.pattern_io.write(motifs, output_handle)
 
         # read 'em back
-        input_handle = open(self.test_file, "r")
-        read_motifs = self.pattern_io.read(input_handle)
-        input_handle.close()
+        with open(self.test_file, "r") as input_handle:
+            read_motifs = self.pattern_io.read(input_handle)
         self.assertEqual(read_motifs, motifs,
                          "Failed to get back expected motifs %s, got %s"
                          % (motifs, read_motifs))
@@ -68,59 +68,50 @@ class PatternIOTest(unittest.TestCase):
         seq_motifs = []
         for motif in motifs:
             seq_motifs.append(Seq(motif, self.alphabet))
-        output_handle = open(self.test_file, "w")
-        self.pattern_io.write_seq(seq_motifs, output_handle)
-        output_handle.close()
+        with open(self.test_file, "w") as output_handle:
+            self.pattern_io.write_seq(seq_motifs, output_handle)
 
         # read the seqs back
-        input_handle = open(self.test_file, "r")
-        read_motifs = self.pattern_io.read(input_handle)
-        input_handle.close()
+        with open(self.test_file, "r") as input_handle:
+            read_motifs = self.pattern_io.read(input_handle)
         self.assertEqual(read_motifs, motifs,
                          "Failed to get back expected motifs %s from seqs, got %s"
                          % (motifs, read_motifs))
 
     def test_schema(self):
-        """Reading and writing schemas to a file.
-        """
+        """Reading and writing schemas to a file."""
         schemas = ["GTR", "GAC"]
         # write out the schemas
-        output_handle = open(self.test_file, "w")
-        self.pattern_io.write(schemas, output_handle)
-        output_handle.close()
+        with open(self.test_file, "w") as output_handle:
+            self.pattern_io.write(schemas, output_handle)
 
         # read back the schemas
-        input_handle = open(self.test_file, "r")
-        read_schemas = self.pattern_io.read(input_handle)
-        input_handle.close()
+        with open(self.test_file, "r") as input_handle:
+            read_schemas = self.pattern_io.read(input_handle)
         self.assertEqual(schemas, read_schemas,
-                         "Read incorrect schemas %s, expected %s."
-                         % (read_schemas, schemas))
+                             "Read incorrect schemas %s, expected %s."
+                             % (read_schemas, schemas))
 
         # --- make sure inappropriate alphabets are reported
-        schemas = ["GTR", "G*C"] # '*' not in the unambigous alphabet
-        output_handle = open(self.test_file, "w")
-        self.pattern_io.write(schemas, output_handle)
-        output_handle.close()
+        schemas = ["GTR", "G*C"]  # '*' not in the unambigous alphabet
+        with open(self.test_file, "w") as output_handle:
+            self.pattern_io.write(schemas, output_handle)
 
         input_handle = open(self.test_file, "r")
         try:
             read_schemas = self.pattern_io.read(input_handle)
             raise AssertionError("Did not report error on bad alphabet.")
         except ValueError:
-            pass # expected behavior
-        except:
+            pass  # expected behavior
+        except Exception:
             raise AssertionError("Got unexpected error while reading.")
-
         input_handle.close()
 
     def test_signature(self):
-        """Reading and writing signatures to a file.
-        """
+        """Reading and writing signatures to a file."""
         signatures = [("GAC", "GAC"), ("AAA", "TTT")]
-        output_handle = open(self.test_file, "w")
-        self.pattern_io.write(signatures, output_handle)
-        output_handle.close()
+        with open(self.test_file, "w") as output_handle:
+            self.pattern_io.write(signatures, output_handle)
 
         input_handle = open(self.test_file, "r")
         read_sigs = self.pattern_io.read(input_handle)
@@ -131,20 +122,18 @@ class PatternIOTest(unittest.TestCase):
 
 
 class PatternRepositoryTest(unittest.TestCase):
-    """Tests for retrieving info from a repository of patterns.
-    """
+    """Tests for retrieving info from a repository of patterns."""
     def setUp(self):
-        self.motifs = {"GATC" : 30,
-                       "GGGG" : 10,
-                       "GTAG" : 0,
-                       "AAAA" : -10,
-                       "ATAT" : -20}
+        self.motifs = {"GATC": 30,
+                       "GGGG": 10,
+                       "GTAG": 0,
+                       "AAAA": -10,
+                       "ATAT": -20}
 
         self.repository = Pattern.PatternRepository(self.motifs)
 
     def test_get_all(self):
-        """Retrieve all patterns from a repository.
-        """
+        """Retrieve all patterns from a repository."""
         all_motifs = self.repository.get_all()
 
         self.assertEqual(all_motifs,
@@ -152,8 +141,7 @@ class PatternRepositoryTest(unittest.TestCase):
                          "Unexpected motifs returned %s" % all_motifs)
 
     def test_get_random(self):
-        """Retrieve random patterns from the repository.
-        """
+        """Retrieve random patterns from the repository."""
         for num_patterns in range(5):
             patterns = self.repository.get_random(num_patterns)
             self.assertEqual(len(patterns), num_patterns,
@@ -161,12 +149,11 @@ class PatternRepositoryTest(unittest.TestCase):
                              % (len(patterns), num_patterns))
 
             for pattern in patterns:
-                self.assertTrue(pattern in list(self.motifs.keys()),
+                self.assertIn(pattern, list(self.motifs.keys()),
                                 "Got unexpected pattern %s" % pattern)
 
     def test_get_top_percentage(self):
-        """Retrieve the top percentge of patterns from the repository.
-        """
+        """Retrieve the top percentge of patterns from the repository."""
         for num_patterns, percentage in ((1, 0.2), (2, .4), (5, 1.0)):
             patterns = self.repository.get_top_percentage(percentage)
             self.assertEqual(len(patterns), num_patterns,
@@ -174,12 +161,11 @@ class PatternRepositoryTest(unittest.TestCase):
                              % (len(patterns), num_patterns))
 
             for pattern in patterns:
-                self.assertTrue(pattern in list(self.motifs.keys()),
+                self.assertIn(pattern, list(self.motifs.keys()),
                                 "Got unexpected pattern %s" % pattern)
 
     def test_get_top(self):
-        """Retrieve a certain number of the top patterns.
-        """
+        """Retrieve a certain number of the top patterns."""
         for num_patterns in range(5):
             patterns = self.repository.get_top(num_patterns)
             self.assertEqual(len(patterns), num_patterns,
@@ -187,20 +173,18 @@ class PatternRepositoryTest(unittest.TestCase):
                              % (len(patterns), num_patterns))
 
             for pattern in patterns:
-                self.assertTrue(pattern in list(self.motifs.keys()),
+                self.assertIn(pattern, list(self.motifs.keys()),
                                 "Got unexpected pattern %s" % pattern)
 
     def test_get_differing(self):
-        """Retrieve patterns from both sides of the list (top and bottom).
-        """
+        """Retrieve patterns from both sides of the list (top and bottom)."""
         patterns = self.repository.get_differing(2, 2)
         self.assertEqual(patterns,
                          ["GATC", "GGGG", "AAAA", "ATAT"],
                          "Got unexpected patterns %s" % patterns)
 
     def test_remove_polyA(self):
-        """Test the ability to remove A rich patterns from the repository.
-        """
+        """Test the ability to remove A rich patterns from the repository."""
         patterns = self.repository.get_all()
         self.assertEqual(len(patterns), 5,
                          "Unexpected starting: %s" % patterns)
@@ -215,8 +199,7 @@ class PatternRepositoryTest(unittest.TestCase):
                          "Unexpected patterns: %s" % patterns)
 
     def test_count(self):
-        """Retrieve counts for particular patterns in the repository.
-        """
+        """Retrieve counts for particular patterns in the repository."""
         num_times = self.repository.count("GGGG")
         self.assertEqual(num_times, 10,
                          "Did not count item in the respository: %s" % num_times)
@@ -229,8 +212,7 @@ class PatternRepositoryTest(unittest.TestCase):
 # --- Tests for motifs
 
 class MotifFinderTest(unittest.TestCase):
-    """Tests for finding motifs from sequences.
-    """
+    """Tests for finding motifs from sequences."""
     def setUp(self):
         test_file = os.path.join('NeuralNetwork', 'enolase.fasta')
         diff_file = os.path.join('NeuralNetwork', 'repeat.fasta')
@@ -261,8 +243,7 @@ class MotifFinderTest(unittest.TestCase):
         self.motif_finder = Motif.MotifFinder()
 
     def test_find(self):
-        """Find all motifs in a set of sequences.
-        """
+        """Find all motifs in a set of sequences."""
         motif_repository = self.motif_finder.find(self.test_records, 8)
         top_motif = motif_repository.get_top(1)
 
@@ -270,8 +251,7 @@ class MotifFinderTest(unittest.TestCase):
                          "Got unexpected motif %s" % top_motif[0])
 
     def test_find_differences(self):
-        """Find the difference in motif counts between two sets of sequences.
-        """
+        """Find the difference in motif counts between two sets of sequences."""
         motif_repository = \
                self.motif_finder.find_differences(self.test_records,
                                                   self.diff_records, 8)
@@ -283,10 +263,17 @@ class MotifFinderTest(unittest.TestCase):
         self.assertEqual(bottom, "AATGGCAT",
                          "Got unexpected bottom motif %s" % bottom)
 
+    def test_inconsistent_alphabets(self):
+        """Find all motifs in a set of sequences."""
+        record1 = SeqRecord(Seq('AAA', alphabet=IUPAC.unambiguous_dna))
+        record2 = SeqRecord(Seq('AAA', alphabet=IUPAC.ambiguous_dna))
+        bad_records = [record1, record2]
+        with self.assertRaises(ValueError):
+            self.motif_finder.find(bad_records, 3)
+
 
 class MotifCoderTest(unittest.TestCase):
-    """Test the ability to encode sequences as a set of motifs.
-    """
+    """Test the ability to encode sequences as a set of motifs."""
     def setUp(self):
         motifs = ["GAG", "GAT", "GCC", "ATA"]
 
@@ -296,8 +283,7 @@ class MotifCoderTest(unittest.TestCase):
         self.coder = Motif.MotifCoder(motifs)
 
     def test_representation(self):
-        """Convert a sequence into its motif representation.
-        """
+        """Convert a sequence into its motif representation."""
         for match_string, expected in self.match_strings:
             seq_to_code = Seq(match_string, IUPAC.unambiguous_dna)
             matches = self.coder.representation(seq_to_code)
@@ -310,15 +296,14 @@ class MotifCoderTest(unittest.TestCase):
 # --- Tests for schemas
 
 class SchemaTest(unittest.TestCase):
-    """Matching ambiguous motifs with multiple ambiguity characters.
-    """
+    """Matching ambiguous motifs with multiple ambiguity characters."""
     def setUp(self):
-        ambiguity_chars = {"G" : "G",
-                           "A" : "A",
-                           "T" : "T",
-                           "C" : "C",
-                           "R" : "AG",
-                           "*" : "AGTC"}
+        ambiguity_chars = {"G": "G",
+                           "A": "A",
+                           "T": "T",
+                           "C": "C",
+                           "R": "AG",
+                           "*": "AGTC"}
 
         self.motif_coder = Schema.Schema(ambiguity_chars)
 
@@ -330,8 +315,7 @@ class SchemaTest(unittest.TestCase):
                            ("*A", ["GA", "TA"])]
 
     def test_find_matches(self):
-        """Find all matches in a sequence.
-        """
+        """Find all matches in a sequence."""
         for motif, expected in self.match_info:
             found_matches = self.motif_coder.find_matches(motif,
                                                           self.match_string)
@@ -340,8 +324,7 @@ class SchemaTest(unittest.TestCase):
                              % (expected, found_matches))
 
     def test_num_matches(self):
-        """Find how many matches are present in a sequence.
-        """
+        """Find how many matches are present in a sequence."""
         for motif, expected in self.match_info:
             num_matches = self.motif_coder.num_matches(motif,
                                                        self.match_string)
@@ -350,8 +333,7 @@ class SchemaTest(unittest.TestCase):
                              % (num_matches, len(expected)))
 
     def test_find_ambiguous(self):
-        """Find the positions of ambiguous items in a sequence.
-        """
+        """Find the positions of ambiguous items in a sequence."""
         ambig_info = (("GATC", []),
                       ("G***", [1, 2, 3]),
                       ("GART", [2]),
@@ -364,8 +346,7 @@ class SchemaTest(unittest.TestCase):
                              % (expected, found_positions, motif))
 
     def test_num_ambiguous(self):
-        """Find the number of ambiguous items in a sequence.
-        """
+        """Find the number of ambiguous items in a sequence."""
         ambig_info = (("GATC", 0),
                       ("G***", 3),
                       ("GART", 1),
@@ -378,8 +359,7 @@ class SchemaTest(unittest.TestCase):
                              % (expected, found_num, motif))
 
     def test_motif_cache(self):
-        """Make sure motif compiled regular expressions are cached properly.
-        """
+        """Make sure motif compiled regular expressions are cached properly."""
         test_motif = "GATC"
 
         self.motif_coder.find_matches(test_motif, "GATCGATC")
@@ -391,8 +371,7 @@ class SchemaTest(unittest.TestCase):
         self.motif_coder.find_matches(test_motif, "GATCGATC")
 
     def test_all_unambiguous(self):
-        """Return all unambiguous characters that can be in a motif.
-        """
+        """Return all unambiguous characters that can be in a motif."""
         found_unambig = self.motif_coder.all_unambiguous()
 
         expected = ["A", "C", "G", "T"]
@@ -401,8 +380,7 @@ class SchemaTest(unittest.TestCase):
 
 
 class SchemaFinderTest(unittest.TestCase):
-    """Test finding schemas from a set of sequences.
-    """
+    """Test finding schemas from a set of sequences."""
     def setUp(self):
         test_file = os.path.join('NeuralNetwork', 'enolase.fasta')
         diff_file = os.path.join('NeuralNetwork', 'repeat.fasta')
@@ -422,12 +400,11 @@ class SchemaFinderTest(unittest.TestCase):
         self.num_schemas = 2
         schema_ga = Schema.GeneticAlgorithmFinder()
         schema_ga.min_generations = 1
-        self.finder = Schema.SchemaFinder(num_schemas = self.num_schemas,
-                                          schema_finder = schema_ga)
+        self.finder = Schema.SchemaFinder(num_schemas=self.num_schemas,
+                                          schema_finder=schema_ga)
 
     def test_find(self):
-        """Find schemas from sequence inputs.
-        """
+        """Find schemas from sequence inputs."""
         # this test takes too long
         if VERBOSE:
             repository = self.finder.find(self.test_records + self.diff_records)
@@ -437,8 +414,7 @@ class SchemaFinderTest(unittest.TestCase):
                             "Got too few schemas.")
 
     def test_find_differences(self):
-        """Find schemas that differentiate between two sets of sequences.
-        """
+        """Find schemas that differentiate between two sets of sequences."""
         # this test takes too long
         if VERBOSE:
             repository = self.finder.find_differences(self.test_records,
@@ -450,15 +426,14 @@ class SchemaFinderTest(unittest.TestCase):
 
 
 class SchemaCoderTest(unittest.TestCase):
-    """Test encoding sequences as a grouping of motifs.
-    """
+    """Test encoding sequences as a grouping of motifs."""
     def setUp(self):
-        ambiguity_chars = {"G" : "G",
-                           "A" : "A",
-                           "T" : "T",
-                           "C" : "C",
-                           "R" : "AG",
-                           "*" : "AGTC"}
+        ambiguity_chars = {"G": "G",
+                           "A": "A",
+                           "T": "T",
+                           "C": "C",
+                           "R": "AG",
+                           "*": "AGTC"}
 
         motif_representation = Schema.Schema(ambiguity_chars)
         motifs = ("GA", "GATAG", "GA*AG", "GATRG", "*A")
@@ -471,8 +446,7 @@ class SchemaCoderTest(unittest.TestCase):
                                             1])]
 
     def test_representation(self):
-        """Convert a string into a representation of motifs.
-        """
+        """Convert a string into a representation of motifs."""
         for match_string, expected in self.match_strings:
             match_seq = Seq(match_string, IUPAC.unambiguous_dna)
             found_rep = self.motif_coder.representation(match_seq)
@@ -481,8 +455,8 @@ class SchemaCoderTest(unittest.TestCase):
 
 
 class SchemaMatchingTest(unittest.TestCase):
-    """Matching schema to strings works correctly.
-    """
+    """Matching schema to strings works correctly."""
+
     def shortDescription(self):
         return "%s:%s" % (self.__class__.__name__, self.__doc__)
 
@@ -509,9 +483,9 @@ class SchemaMatchingTest(unittest.TestCase):
 
 
 class SchemaFactoryTest(unittest.TestCase):
-    """Test the SchemaFactory for generating Schemas.
-    """
+    """Test the SchemaFactory for generating Schemas."""
     def __init__(self, method):
+        """Initialize."""
         unittest.TestCase.__init__(self, method)
 
         # a cached schema bank, so we don't have to load it multiple times
@@ -522,25 +496,39 @@ class SchemaFactoryTest(unittest.TestCase):
 
         self.test_file = os.path.join(os.getcwd(), "NeuralNetwork", "enolase.fasta")
 
-        ambiguity_chars = {"G" : "G",
-                           "A" : "A",
-                           "T" : "T",
-                           "C" : "C",
-                           "R" : "AG",
-                           "*" : "AGTC"}
+        ambiguity_chars = {"G": "G",
+                           "A": "A",
+                           "T": "T",
+                           "C": "C",
+                           "R": "AG",
+                           "*": "AGTC"}
 
         self.schema = Schema.Schema(ambiguity_chars)
+        self.motifs = {"GATCGAA": 20,
+                       "GATCGAT": 15,
+                       "GATTGAC": 25,
+                       "TTTTTTT": 10}
+
+    def test_no_motifs(self):
+        """Test generating schema when no motif given."""
+        motif_bank = Pattern.PatternRepository({})
+        with self.assertRaises(ValueError):
+            self.factory.from_motifs(motif_bank, .5, 2)
+
+    def test_exceed_maximum_tries(self):
+        """Test maximum tries exceeded."""
+        with self.assertRaises(RuntimeError):
+            self.factory._get_unique_schema(['A*'], ['AT'], 1)
+
+    def test_unexpected_motif(self):
+        """Test when unexpected motif found."""
+        with self.assertRaises(ValueError):
+            self.factory._schema_from_motif(
+                'AAAAAAA', self.motifs.keys(), 1)
 
     def test_easy_from_motifs(self):
-        """Generating schema from a simple list of motifs.
-        """
-        motifs = {"GATCGAA" : 20,
-                  "GATCGAT" : 15,
-                  "GATTGAC" : 25,
-                  "TTTTTTT" : 10}
-
-        motif_bank = Pattern.PatternRepository(motifs)
-
+        """Generating schema from a simple list of motifs."""
+        motif_bank = Pattern.PatternRepository(self.motifs)
         schema_bank = self.factory.from_motifs(motif_bank, .5, 2)
         if VERBOSE:
             print("\nSchemas:")
@@ -548,8 +536,7 @@ class SchemaFactoryTest(unittest.TestCase):
                 print("%s: %s" % (schema, schema_bank.count(schema)))
 
     def test_hard_from_motifs(self):
-        """Generating schema from a real life set of motifs.
-        """
+        """Generating schema from a real life set of motifs."""
         schema_bank = self._load_schema_repository()
 
         if VERBOSE:
@@ -589,8 +576,7 @@ class SchemaFactoryTest(unittest.TestCase):
         return schema_bank
 
     def test_schema_representation(self):
-        """Convert sequences into schema representations.
-        """
+        """Convert sequences into schema representations."""
         # get a set of schemas we want to code the sequence in
         schema_bank = self._load_schema_repository()
         top_schemas = schema_bank.get_top(25)
@@ -608,8 +594,7 @@ class SchemaFactoryTest(unittest.TestCase):
 
 # --- Tests for Signatures
 class SignatureFinderTest(unittest.TestCase):
-    """Test the ability to find signatures in a set of sequences.
-    """
+    """Test the ability to find signatures in a set of sequences."""
     def setUp(self):
         test_file = os.path.join('NeuralNetwork', 'enolase.fasta')
 
@@ -624,8 +609,7 @@ class SignatureFinderTest(unittest.TestCase):
         self.sig_finder = Signature.SignatureFinder()
 
     def test_find(self):
-        """Find signatures from sequence inputs.
-        """
+        """Find signatures from sequence inputs."""
         repository = self.sig_finder.find(self.test_records, 6, 9)
         top_sig = repository.get_top(1)
 
@@ -633,8 +617,7 @@ class SignatureFinderTest(unittest.TestCase):
 
 
 class SignatureCoderTest(unittest.TestCase):
-    """Test the ability to encode sequences as a set of signatures.
-    """
+    """Test the ability to encode sequences as a set of signatures."""
     def setUp(self):
         signatures = [("GAC", "GAC"), ("AAA", "TTT"), ("CAA", "TTG")]
 
@@ -648,8 +631,7 @@ class SignatureCoderTest(unittest.TestCase):
                           ("GACAAAAAAAAAAGAC", [0.0, 0.0, 0.0])]
 
     def test_representation(self):
-        """Convert a sequence into its signature representation.
-        """
+        """Convert a sequence into its signature representation."""
         for seq_string, expected in self.test_seqs:
             test_seq = Seq(seq_string, IUPAC.unambiguous_dna)
             predicted = self.coder.representation(test_seq)
@@ -658,6 +640,11 @@ class SignatureCoderTest(unittest.TestCase):
                              "Non-expected representation %s for %s, wanted %s"
                              % (predicted, seq_string, expected))
 
+    def test_inconsistent_signature_sizes(self):
+        with self.assertRaises(ValueError):
+            Signature.SignatureCoder([('GAC', 'GAC'), ('AA', 'TTT')], 1)
+
+
 if __name__ == "__main__":
-    runner = unittest.TextTestRunner(verbosity = 2)
+    runner = unittest.TextTestRunner(verbosity=2)
     unittest.main(testRunner=runner)
