@@ -1,16 +1,25 @@
-#!/usr/bin/env python
+# Copyright 2001 Brad Chapman.  All rights reserved.
+#
+# This code is part of the Biopython distribution and governed by its
+# license.  Please see the LICENSE file that should have been included
+# as part of this package.
+
 """General test for the NeuralNetwork libraries.
 
 This exercises various elements of the BackPropagation NeuralNetwork
 libraries.
 """
-# standard library
+
 import random
 import unittest
 
-# local stuff
-from Bio.NeuralNetwork.Training import TrainingExample, ExampleManager
-from Bio.NeuralNetwork.StopTraining import ValidationIncreaseStop
+import warnings
+from Bio import BiopythonDeprecationWarning
+with warnings.catch_warnings():
+    warnings.simplefilter('ignore', BiopythonDeprecationWarning)
+    # local stuff
+    from Bio.NeuralNetwork.Training import TrainingExample, ExampleManager
+    from Bio.NeuralNetwork.StopTraining import ValidationIncreaseStop
 
 
 class StopTrainingTest(unittest.TestCase):
@@ -92,6 +101,12 @@ class ExampleManagerTest(unittest.TestCase):
         assert len(manager.validation_examples) == self.num_examples, \
                "Did not partition correctly to validation_examples."
 
+    def test_value_error(self):
+        """Test when the sum of input percentages exceed 1.0"""
+        with self.assertRaises(ValueError):
+            ExampleManager(0.6, 0.6)
+
+
 if __name__ == "__main__":
     runner = unittest.TextTestRunner(verbosity=2)
     unittest.main(testRunner=runner)
