@@ -7,7 +7,14 @@
 import unittest
 from os import path
 
-from Bio.SearchIO import parse, read
+from Bio import BiopythonExperimentalWarning
+
+import warnings
+
+
+with warnings.catch_warnings():
+    warnings.simplefilter('ignore', BiopythonExperimentalWarning)
+    from Bio.SearchIO import parse, read
 
 
 class HmmpfamTests(unittest.TestCase):
@@ -17,7 +24,7 @@ class HmmpfamTests(unittest.TestCase):
     def test_hmmpfam_21(self):
         """Test parsing hmmpfam 2.1 file (text_21_hmmpfam_001.out)"""
         results = parse(path.join("Hmmer", "text_21_hmmpfam_001.out"), self.fmt)
-        res = results.next()
+        res = next(results)
         self.assertEqual('roa1_drome', res.id)
         self.assertEqual('<unknown description>', res.description)
         self.assertEqual('hmmpfam', res.program)
@@ -46,7 +53,7 @@ class HmmpfamTests(unittest.TestCase):
         self.assertEqual('lfVgNLppdvteedLkdlFskfGpivsikivrDiiekpketgkskGfaFVeFeseedAekAlealnG.kelggrklrv',
                          str(hsp.hit.seq))
         self.assertEqual('lf+g+L + +t+e Lk++F+k G iv++ +++D     + t++s+Gf+F+++  ++  + A +    +++++gr+++ ',
-                         str(hsp.aln_annotation['homology']))
+                         str(hsp.aln_annotation['similarity']))
         self.assertEqual('LFIGGLDYRTTDENLKAHFEKWGNIVDVVVMKD-----PRTKRSRGFGFITYSHSSMIDEAQK--SRpHKIDGRVVEP',
                          str(hsp.query.seq))
 
@@ -63,14 +70,14 @@ class HmmpfamTests(unittest.TestCase):
         self.assertEqual('lfVgNLppdvteedLkdlFskfGpivsikivrDiiekpketgkskGfaFVeFeseedAekAlealnGkelggrklrv',
                          str(hsp.hit.seq))
         self.assertEqual('lfVg L  d +e+ ++d+F++fG iv+i+iv+D     ketgk +GfaFVeF++++ ++k +     ++l+g+ + v',
-                         str(hsp.aln_annotation['homology']))
+                         str(hsp.aln_annotation['similarity']))
         self.assertEqual('LFVGALKDDHDEQSIRDYFQHFGNIVDINIVID-----KETGKKRGFAFVEFDDYDPVDKVVL-QKQHQLNGKMVDV',
                          str(hsp.query.seq))
 
     def test_hmmpfam_22(self):
         """Test parsing hmmpfam 2.2 file (text_22_hmmpfam_001.out)"""
         results = parse(path.join("Hmmer", "text_22_hmmpfam_001.out"), self.fmt)
-        res = results.next()
+        res = next(results)
         self.assertEqual('gi|1522636|gb|AAC37060.1|', res.id)
         self.assertEqual('M. jannaschii predicted coding region MJECS02 [Methanococcus jannaschii]', res.description)
         self.assertEqual('[none]', res.accession)
@@ -100,15 +107,14 @@ class HmmpfamTests(unittest.TestCase):
         self.assertEqual('lrnELentLWavADkLRGsmDaseYKdyVLGLlFlKYiSdkFlerrieieerktdtesepsldyakledqyeqlededlekedfyqkkGvFilPsqlFwdfikeaeknkldedigtdldkifseledqialgypaSeedfkGlfpdldfnsnkLgskaqarnetLtelidlfselelgtPmHNG.dfeelgikDlfGDaYEYLLgkFAeneGKsGGeFYTPqeVSkLiaeiLtigqpsegdfsIYDPAcGSGSLllqaskflgehdgkrnaisyYGQEsn',
                          str(hsp.hit.seq))
         self.assertEqual(' ++EL+++  av+   R              L+F K++ dk      +i+         p +   + +++y   ++   ++ ++y ++      + lF++++   e ++  ++++ + +    ++      + +       Glf ++++  ++ +s+   +ne ++e+i+ +++ +++     G++ +el   D++G +YE L+   Ae   K+ G +YTP e++  ia+ + i+  ++                  +++ ++    k+n+i +    s+',
-                         str(hsp.aln_annotation['homology']))
+                         str(hsp.aln_annotation['similarity']))
         self.assertEqual('NTSELDKKKFAVLLMNR--------------LIFIKFLEDK------GIV---------PRDLLRRTYEDY---KKSNVLI-NYYDAY-L----KPLFYEVLNTPEDER--KENIRT-NPYYKDIPYL---N-G-------GLFRSNNV--PNELSFTIKDNEIIGEVINFLERYKFTLSTSEGsEEVELNP-DILGYVYEKLINILAEKGQKGLGAYYTPDEITSYIAKNT-IEPIVVE----------------RFKEIIK--NWKINDINF----ST',
                          str(hsp.query.seq))
 
-
     def test_hmmpfam_23(self):
         """Test parsing hmmpfam 2.3 file (text_23_hmmpfam_001.out)"""
         results = parse(path.join("Hmmer", "text_23_hmmpfam_001.out"), self.fmt)
-        res = results.next()
+        res = next(results)
         self.assertEqual('gi|90819130|dbj|BAE92499.1|', res.id)
         self.assertEqual('glutamate synthase [Porphyra yezoensis]', res.description)
         self.assertEqual('[none]', res.accession)
@@ -138,7 +144,7 @@ class HmmpfamTests(unittest.TestCase):
         self.assertEqual('lPwelgLaevhqtLvengLRdrVsLia',
                          str(hsp.hit.seq))
         self.assertEqual('+P  l++ +vh  L++ gLR + s+ +',
-                         str(hsp.aln_annotation['homology']))
+                         str(hsp.aln_annotation['similarity']))
         self.assertEqual('IPPLLAVGAVHHHLINKGLRQEASILV',
                          str(hsp.query.seq))
 
@@ -156,12 +162,12 @@ class HmmpfamTests(unittest.TestCase):
     def test_hmmpfam_23_no_match(self):
         """Test parsing hmmpfam 2.3 file (text_23_hmmpfam_002.out)"""
         results = parse(path.join("Hmmer", "text_23_hmmpfam_002.out"), self.fmt)
-        res = results.next()
+        res = next(results)
 
         self.assertEqual('SEQ0001', res.id)
         self.assertEqual(0, len(res.hits))
 
-        res = results.next()
+        res = next(results)
 
         self.assertEqual('SEQ0002', res.id)
         self.assertEqual(0, len(res.hits))
@@ -169,7 +175,7 @@ class HmmpfamTests(unittest.TestCase):
     def test_hmmpfam_23_missing_consensus(self):
         """Test parsing hmmpfam 2.3 file (text_23_hmmpfam_003.out)"""
         results = parse(path.join("Hmmer", "text_23_hmmpfam_003.out"), self.fmt)
-        res = results.next()
+        res = next(results)
 
         self.assertEqual('small_input', res.id)
         self.assertEqual('[none]', res.description)
@@ -198,14 +204,24 @@ class HmmpfamTests(unittest.TestCase):
         self.assertAlmostEqual(-79.3, hsp.bitscore)
         self.assertAlmostEqual(1, hsp.evalue)
         self.assertEqual(len(hsp.query.seq), len(hsp.hit.seq))
-        self.assertEqual(len(hsp.query.seq), len(hsp.aln_annotation['homology']))
+        self.assertEqual(len(hsp.query.seq), len(hsp.aln_annotation['similarity']))
         self.assertEqual('msEEqLKAFiAKvqaDtsLqEqLKaEGADvvaiAKAaGFtitteDLnahiqakeLsdeeLEgvaGg',
                          str(hsp.hit.seq))
         self.assertEqual('        F+                           G  +t   Ln                   ',
-                         str(hsp.aln_annotation['homology']))
+                         str(hsp.aln_annotation['similarity']))
         self.assertEqual('-------CFL---------------------------GCLVTNWVLNRS-----------------',
                          str(hsp.query.seq))
 
+    def test_hmmpfam_23_break_in_end_of_seq(self):
+        """Test parsing hmmpfam 2.3 file with a line break in the end of seq marker.
+
+        file (text_23_hmmpfam_004.out)
+        """
+        results = parse(path.join("Hmmer", "text_23_hmmpfam_004.out"), self.fmt)
+        res = next(results)
+        self.assertEqual('PKSI-KS', res[0].id)
+        self.assertEqual('PKSI-FK', res[1].id)
+
     def test_hmmpfam_24(self):
         """Test parsing hmmpfam 2.4 file (text_24_hmmpfam_001.out)"""
         results = list(parse(path.join("Hmmer", "text_24_hmmpfam_001.out"), self.fmt))
@@ -251,7 +267,7 @@ class HmmpfamTests(unittest.TestCase):
         self.assertEqual('ENHIKDALSRIVVEMIKREWPQHWPDMLIELDTLSKQG--',
                 str(hsp.query.seq)[:40])
         self.assertEqual('+++++  L+++++e++k+ewP++Wp+ + +l  l++++  ',
-                str(hsp.aln_annotation['homology'])[:40])
+                str(hsp.aln_annotation['similarity'])[:40])
         self.assertEqual('WVSMSHITA-ENCkLLEILCLLL----NEQELQLGAAECL',
                 str(hsp.query.seq)[-40:])
         self.assertEqual(0, hsp.hit_start)
@@ -260,7 +276,7 @@ class HmmpfamTests(unittest.TestCase):
         self.assertEqual('pkflrnKLalalaelakqewPsnWpsffpdlvsllsssss',
                 str(hsp.hit.seq)[:40])
         self.assertEqual('W+++++i + ++++ll++l+ lL    +  +l++ A+eCL',
-                str(hsp.aln_annotation['homology'])[-40:])
+                str(hsp.aln_annotation['similarity'])[-40:])
         self.assertEqual('Wipiglianvnpi.llnllfslLsgpesdpdlreaAveCL',
                 str(hsp.hit.seq)[-40:])
 
@@ -418,17 +434,17 @@ class HmmsearchTests(unittest.TestCase):
         self.assertEqual(337, hsp.query_end)
         self.assertEqual('[]', hsp.query_endtype)
         self.assertEqual('lPesfDWReWkggaVtpVKdQGiqCGSCWAFSavgalEgr', str(hsp.query.seq)[:40])
-        self.assertEqual('IVKNSWGtdWGEnGYfriaRgknksgkneCGIaseasypi',str(hsp.query.seq)[-40:])
+        self.assertEqual('IVKNSWGtdWGEnGYfriaRgknksgkneCGIaseasypi', str(hsp.query.seq)[-40:])
         self.assertEqual(337, len(hsp.query.seq))
         self.assertEqual('+P+++DWRe kg  VtpVK+QG qCGSCWAFSa g lEg+',
-                str(hsp.aln_annotation['homology'])[:40])
+                str(hsp.aln_annotation['similarity'])[:40])
         self.assertEqual('+VKNSWG++WG++GY++ia+++n    n+CG+a+ asypi',
-                str(hsp.aln_annotation['homology'])[-40:])
+                str(hsp.aln_annotation['similarity'])[-40:])
         self.assertEqual(113, hsp.hit_start)
         self.assertEqual(332, hsp.hit_end)
         self.assertEqual('..', hsp.hit_endtype)
         self.assertEqual('IPKTVDWRE-KG-CVTPVKNQG-QCGSCWAFSASGCLEGQ', str(hsp.hit.seq)[:40])
-        self.assertEqual('LVKNSWGKEWGMDGYIKIAKDRN----NHCGLATAASYPI',str(hsp.hit.seq)[-40:])
+        self.assertEqual('LVKNSWGKEWGMDGYIKIAKDRN----NHCGLATAASYPI', str(hsp.hit.seq)[-40:])
         self.assertEqual(337, len(hsp.hit.seq))
 
         # last hit
@@ -453,17 +469,17 @@ class HmmsearchTests(unittest.TestCase):
         self.assertEqual(337, hsp.query_end)
         self.assertEqual('[]', hsp.query_endtype)
         self.assertEqual('lPesfDWReWkggaVtpVKdQGiqCGSCWAFSavgalEgr', str(hsp.query.seq)[:40])
-        self.assertEqual('IVKNSWGtdWGEnGYfriaRgknksgkneCGIaseasypi',str(hsp.query.seq)[-40:])
+        self.assertEqual('IVKNSWGtdWGEnGYfriaRgknksgkneCGIaseasypi', str(hsp.query.seq)[-40:])
         self.assertEqual(337, len(hsp.query.seq))
         self.assertEqual('+Pe +DWR+ kg aVtpVK+QG +CGSCWAFSav ++Eg+',
-                str(hsp.aln_annotation['homology'])[:40])
+                str(hsp.aln_annotation['similarity'])[:40])
         self.assertEqual('++KNSWGt WGEnGY+ri+Rg+++s ++ CG+ ++  yp+',
-                str(hsp.aln_annotation['homology'])[-40:])
+                str(hsp.aln_annotation['similarity'])[-40:])
         self.assertEqual(133, hsp.hit_start)
         self.assertEqual(343, hsp.hit_end)
         self.assertEqual('..', hsp.hit_endtype)
         self.assertEqual('IPEYVDWRQ-KG-AVTPVKNQG-SCGSCWAFSAVVTIEGI', str(hsp.hit.seq)[:40])
-        self.assertEqual('LIKNSWGTGWGENGYIRIKRGTGNS-YGVCGLYTSSFYPV',str(hsp.hit.seq)[-40:])
+        self.assertEqual('LIKNSWGTGWGENGYIRIKRGTGNS-YGVCGLYTSSFYPV', str(hsp.hit.seq)[-40:])
         self.assertEqual(337, len(hsp.hit.seq))
 
 
