@@ -4,14 +4,14 @@
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 
-from __future__ import with_statement
+from __future__ import print_function
 
 import unittest
-from StringIO import StringIO
+from Bio._py3k import StringIO
 
 from Bio import SeqIO
 from Bio.SeqIO.FastaIO import FastaIterator
-from Bio.Alphabet import generic_protein, generic_nucleotide, generic_dna
+from Bio.Alphabet import generic_nucleotide, generic_dna
 
 
 def title_to_ids(title):
@@ -30,12 +30,12 @@ def title_to_ids(title):
     # now extract the ids from the id block
     # gi|5690369|gb|AF158246.1|AF158246
     id_info_items = id_info.split("|")
-    if len(id_info_items) >=4:
+    if len(id_info_items) >= 4:
         assert id_info_items[2] in ["gb", "emb", "dbj", "pdb"], title
-        id = id_info_items[3] # the id with version info
-        name = id_info_items[4] # the id without version info
+        id = id_info_items[3]  # the id with version info
+        name = id_info_items[4]  # the id without version info
     else:
-        #Fallback:
+        # Fallback:
         id = id_info_items[0]
         name = id_info_items[0]
 
@@ -44,38 +44,59 @@ def title_to_ids(title):
 
 def read_single_with_titles(filename, alphabet):
     global title_to_ids
-    handle = open(filename)
-    iterator = FastaIterator(handle, alphabet, title_to_ids)
-    record = iterator.next()
-    try:
-        second = iterator.next()
-    except StopIteration:
-        second = None
-    handle.close()
+    with open(filename) as handle:
+        iterator = FastaIterator(handle, alphabet, title_to_ids)
+        record = next(iterator)
+        try:
+            second = next(iterator)
+        except StopIteration:
+            second = None
     assert record is not None and second is None
     return record
 
 
 def read_title_and_seq(filename):
     """Crude parser that gets the first record from a FASTA file."""
-    handle = open(filename)
-    title = handle.readline().rstrip()
-    assert title.startswith(">")
-    seq = ""
-    for line in handle:
-        if line.startswith(">"):
-            break
-        seq += line.strip()
-    handle.close()
+    with open(filename) as handle:
+        title = handle.readline().rstrip()
+        assert title.startswith(">")
+        seq = ""
+        for line in handle:
+            if line.startswith(">"):
+                break
+            seq += line.strip()
     return title[1:], seq
 
 
+class Wrapping(unittest.TestCase):
+    """Tests for two-line-per-record FASTA variant."""
+
+    def test_fails(self):
+        self.assertRaises(ValueError, SeqIO.read, "Fasta/aster.pro", "fasta-2line")
+
+    def test_passes(self):
+        expected = SeqIO.read("Fasta/aster.pro", "fasta")
+
+        record = SeqIO.read("Fasta/aster_no_wrap.pro", "fasta")
+        self.assertEqual(expected.id, record.id)
+        self.assertEqual(expected.name, record.name)
+        self.assertEqual(expected.description, record.description)
+        self.assertEqual(expected.seq, record.seq)
+
+        record = SeqIO.read("Fasta/aster_no_wrap.pro", "fasta-2line")
+        self.assertEqual(expected.id, record.id)
+        self.assertEqual(expected.name, record.name)
+        self.assertEqual(expected.description, record.description)
+        self.assertEqual(expected.seq, record.seq)
+
+
 class TitleFunctions(unittest.TestCase):
     """Cunning unit test where methods are added at run time."""
+
     def simple_check(self, filename, alphabet):
         """Basic test for parsing single record FASTA files."""
         title, seq = read_title_and_seq(filename)  # crude parser
-        #First check using Bio.SeqIO.FastaIO directly with title function,
+        # First check using Bio.SeqIO.FastaIO directly with title function,
         record = read_single_with_titles(filename, alphabet)
         idn, name, descr = title_to_ids(title)
         self.assertEqual(record.id, idn)
@@ -83,15 +104,15 @@ class TitleFunctions(unittest.TestCase):
         self.assertEqual(record.description, descr)
         self.assertEqual(str(record.seq), seq)
         self.assertEqual(record.seq.alphabet, alphabet)
-        #Now check using Bio.SeqIO (default settings)
+        # Now check using Bio.SeqIO (default settings)
         record = SeqIO.read(filename, "fasta", alphabet)
         self.assertEqual(record.id, title.split()[0])
         self.assertEqual(record.name, title.split()[0])
         self.assertEqual(record.description, title)
         self.assertEqual(str(record.seq), seq)
         self.assertEqual(record.seq.alphabet, alphabet)
-        #Uncomment this for testing the methods are calling the right files:
-        #print "{%s done}" % filename,
+        # Uncomment this for testing the methods are calling the right files:
+        # print("{%s done}" % filename)
 
     def multi_check(self, filename, alphabet):
         """Basic test for parsing multi-record FASTA files."""
@@ -106,8 +127,8 @@ class TitleFunctions(unittest.TestCase):
             self.assertEqual(new.description, descr)
             self.assertEqual(str(new.seq), str(old.seq))
             self.assertEqual(new.seq.alphabet, old.seq.alphabet)
-        #Uncomment this for testing the methods are calling the right files:
-        #print "{%s done}" % filename,
+        # Uncomment this for testing the methods are calling the right files:
+        # print("{%s done}" % filename)
 
     def test_no_name(self):
         """Test FASTA record with no identifier."""
@@ -136,46 +157,46 @@ for filename in single_nucleic_files:
     name = filename.split(".")[0]
 
     def funct(fn):
-        f = lambda x : x.simple_check(fn, generic_nucleotide)
+        f = lambda x: x.simple_check(fn, generic_nucleotide)
         f.__doc__ = "Checking nucleotide file %s" % fn
         return f
 
-    setattr(TitleFunctions, "test_nuc_%s"%name, funct(filename))
+    setattr(TitleFunctions, "test_nuc_%s" % name, funct(filename))
     del funct
 
 for filename in multi_dna_files:
     name = filename.split(".")[0]
 
     def funct(fn):
-        f = lambda x : x.multi_check(fn, generic_dna)
+        f = lambda x: x.multi_check(fn, generic_dna)
         f.__doc__ = "Checking multi DNA file %s" % fn
         return f
 
-    setattr(TitleFunctions, "test_mutli_dna_%s"%name, funct(filename))
+    setattr(TitleFunctions, "test_mutli_dna_%s" % name, funct(filename))
     del funct
 
 for filename in single_amino_files:
     name = filename.split(".")[0]
 
     def funct(fn):
-        f = lambda x : x.simple_check(fn, generic_nucleotide)
+        f = lambda x: x.simple_check(fn, generic_nucleotide)
         f.__doc__ = "Checking protein file %s" % fn
         return f
 
-    setattr(TitleFunctions, "test_pro_%s"%name, funct(filename))
+    setattr(TitleFunctions, "test_pro_%s" % name, funct(filename))
     del funct
 
 for filename in multi_amino_files:
     name = filename.split(".")[0]
 
     def funct(fn):
-        f = lambda x : x.multi_check(fn, generic_dna)
+        f = lambda x: x.multi_check(fn, generic_dna)
         f.__doc__ = "Checking multi protein file %s" % fn
         return f
 
-    setattr(TitleFunctions, "test_mutli_pro_%s"%name, funct(filename))
+    setattr(TitleFunctions, "test_mutli_pro_%s" % name, funct(filename))
     del funct
 
 if __name__ == "__main__":
-    runner = unittest.TextTestRunner(verbosity = 2)
+    runner = unittest.TextTestRunner(verbosity=2)
     unittest.main(testRunner=runner)
