@@ -3,21 +3,21 @@
 # license.  Please see the LICENSE file that should have been included
 # as part of this package.
 
-"""Testing Bio.TogoWS online code.
-"""
+"""Testing Bio.TogoWS online code."""
 
-from __future__ import with_statement
+from __future__ import print_function
 
 import unittest
-from StringIO import StringIO
+from Bio._py3k import StringIO
+from Bio._py3k import HTTPError
 
 import requires_internet
 requires_internet.check()
 
-#We want to test these:
+# We want to test these:
 from Bio import TogoWS
 
-#In order to check any sequences returned
+# In order to check any sequences returned
 from Bio import SeqIO
 from Bio.SeqUtils.CheckSum import seguid
 from Bio import Medline
@@ -37,7 +37,7 @@ class TogoFields(unittest.TestCase):
         expected = set(['nuccore', 'nucest', 'nucgss',
                         'nucleotide', 'protein', 'gene',
                         'homologene', 'snp',
-                        'mesh', 'pubmed', 'embl',
+                        'mesh', 'pubmed',  # 'embl',
                         'uniprot', 'uniparc', 'uniref100',
                         'uniref90', 'uniref50', 'ddbj',
                         'dad', 'pdb', 'compound', 'drug',
@@ -51,7 +51,7 @@ class TogoFields(unittest.TestCase):
         """Check supported fields for pubmed database"""
         fields = set(TogoWS._get_entry_fields("pubmed"))
         self.assertTrue(fields.issuperset(['abstract', 'au', 'authors',
-                                           'doi', 'mesh', 'so', 'ti',
+                                           'doi', 'mesh', 'so',
                                            'title']), fields)
 
     def test_ncbi_protein(self):
@@ -78,12 +78,6 @@ class TogoFields(unittest.TestCase):
                                            'taxonomy', 'comment', 'seq']),
                                            fields)
 
-    def test_embl(self):
-        """Check supported fields for embl database"""
-        fields = set(TogoWS._get_entry_fields("embl"))
-        self.assertTrue(fields.issuperset(["definition", "entry_id", "seq"]),
-                        fields)
-
     def test_uniprot(self):
         """Check supported fields for uniprot database"""
         fields = set(TogoWS._get_entry_fields("uniprot"))
@@ -100,7 +94,7 @@ class TogoFields(unittest.TestCase):
 class TogoEntry(unittest.TestCase):
     def test_pubmed_16381885(self):
         """Bio.TogoWS.entry("pubmed", "16381885")"""
-        #Gives Medline plain text
+        # Gives Medline plain text
         handle = TogoWS.entry("pubmed", "16381885")
         data = Medline.read(handle)
         handle.close()
@@ -112,8 +106,8 @@ class TogoEntry(unittest.TestCase):
                                       'Hirakawa M'])
 
     def test_pubmed_16381885_ti(self):
-        """Bio.TogoWS.entry("pubmed", "16381885", field="ti")"""
-        handle = TogoWS.entry("pubmed", "16381885", field="ti")
+        """Bio.TogoWS.entry("pubmed", "16381885", field="title")"""
+        handle = TogoWS.entry("pubmed", "16381885", field="title")
         data = handle.read().strip()
         handle.close()
         self.assertEqual(data,
@@ -129,7 +123,7 @@ class TogoEntry(unittest.TestCase):
 
     def test_pubmed_16381885_au(self):
         """Bio.TogoWS.entry("pubmed", "16381885", field="au")"""
-        #Gives one name per line (i.e. \n separated), no dots
+        # Gives one name per line (i.e. \n separated), no dots
         handle = TogoWS.entry("pubmed", "16381885", field="au")
         data = handle.read().strip().split("\n")
         handle.close()
@@ -140,7 +134,7 @@ class TogoEntry(unittest.TestCase):
 
     def test_pubmed_16381885_authors(self):
         """Bio.TogoWS.entry("pubmed", "16381885", field="authors")"""
-        #Gives names tab separated (i.e. \t separated)
+        # Gives names tab separated (i.e. \t separated)
         handle = TogoWS.entry("pubmed", "16381885", field="authors")
         data = handle.read().strip().split("\t")
         handle.close()
@@ -188,8 +182,8 @@ class TogoEntry(unittest.TestCase):
     def test_pubmed_16381885_and_19850725_authors(self):
         """Bio.TogoWS.entry("pubmed", "16381885,19850725", field="authors")"""
         handle = TogoWS.entry("pubmed", "16381885,19850725", field="authors")
-        #Little hack to remove blank lines...
-        #names = handle.read().replace("\n\n", "\n").strip().split("\n")
+        # Little hack to remove blank lines...
+        # names = handle.read().replace("\n\n", "\n").strip().split("\n")
         names = handle.read().strip().split("\n")
         handle.close()
         self.assertEqual(2, len(names))
@@ -212,13 +206,13 @@ class TogoEntry(unittest.TestCase):
     def test_ddbj_genbank_length(self):
         """Bio.TogoWS.entry("ddbj", "X52960", field="length")"""
         handle = TogoWS.entry("ddbj", "X52960", field="length")
-        data = handle.read().strip()  #ignore trailing \n
+        data = handle.read().strip()  # ignore trailing \n
         handle.close()
         self.assertEqual(data, "248")
 
     def test_ddbj_genbank(self):
         """Bio.TogoWS.entry("ddbj", "X52960")"""
-        handle = TogoWS.entry("ddbj", "X52960")  #Returns "genbank" format
+        handle = TogoWS.entry("ddbj", "X52960")  # Returns "genbank" format
         record = SeqIO.read(handle, "gb")
         handle.close()
         self.assertEqual(record.id, "X52960.1")
@@ -254,7 +248,7 @@ class TogoEntry(unittest.TestCase):
         handle.close()
         self.assertEqual(data, "X52960")
 
-    def test_nucleotide_genbank_accession(self):
+    def test_nucleotide_genbank_version(self):
         """Bio.TogoWS.entry("nucleotide", "X52960", field="version")"""
         handle = TogoWS.entry("nucleotide", "X52960", field="version")
         data = handle.read().strip()  # ignore trailing \n
@@ -294,58 +288,26 @@ class TogoEntry(unittest.TestCase):
 
     def test_genbank_gff3(self):
         """Bio.TogoWS.entry("nucleotide", "X52960", format="gff")"""
-        #Note - Using manual URL with genbank instead of nucleotide works
+        # Note - Using manual URL with genbank instead of nucleotide works
         handle = TogoWS.entry("nucleotide", "X52960", format="gff")
         data = handle.read()
         handle.close()
         self.assertTrue(data.startswith("##gff-version 3\nX52960\tGenbank\t"), data)
 
-    def test_embl_AM905444_gff3(self):
-        """Bio.TogoWS.entry("embl", "AM905444", format="gff")"""
-        handle = TogoWS.entry("embl", "AM905444", format="gff")
-        data = handle.read()
-        handle.close()
-        self.assertTrue(data.startswith("##gff-version 3\nAM905444\tembl\t"), data)
-
-    def test_embl_AM905444_seq(self):
-        """Bio.TogoWS.entry("embl", "AM905444", field="seq")"""
-        handle = TogoWS.entry("embl", "AM905444", field="seq")
-        data = handle.read().strip()  # ignore any trailing \n
-        handle.close()
-        self.assertEqual(seguid(data), "G0HtLpwF7i4FXUaUjDUPTjok79c")
-
-    def test_embl_AM905444_definition(self):
-        """Bio.TogoWS.entry("embl", "AM905444", field="definition")"""
-        handle = TogoWS.entry("embl", "AM905444", field="definition")
-        data = handle.read().strip()  # ignore any trailing \n
-        handle.close()
-        self.assertEqual(data, "Herbaspirillum seropedicae locus tag HS193.0074 for porin")
-
-    def test_embl_AM905444(self):
-        """Bio.TogoWS.entry("embl", "AM905444")"""
-        handle = TogoWS.entry("embl", "AM905444")
-        record = SeqIO.read(handle, "embl")
-        handle.close()
-        self.assertTrue("AM905444" in record.id, record.id)
-        self.assertTrue("AM905444" in record.name, record.name)
-        self.assertTrue("porin" in record.description, record.description)
-        self.assertEqual(len(record), 1164)
-        self.assertEqual(seguid(record.seq), "G0HtLpwF7i4FXUaUjDUPTjok79c")
-
     def test_ddbj_fasta(self):
         """Bio.TogoWS.entry("ddbj", "X52960", "fasta")"""
         handle = TogoWS.entry("ddbj", "X52960", "fasta")
         record = SeqIO.read(handle, "fasta")
         handle.close()
-        self.assertTrue("X52960" in record.id, record.id)
-        self.assertTrue("X52960" in record.name, record.name)
+        self.assertIn("X52960", record.id)
+        self.assertIn("X52960", record.name)
         self.assertEqual(len(record), 248)
         self.assertEqual(seguid(record.seq), "Ktxz0HgMlhQmrKTuZpOxPZJ6zGU")
 
     def test_uniprot_swiss(self):
         """Bio.TogoWS.entry("uniprot", ["A1AG1_HUMAN","A1AG1_MOUSE"])"""
-        #Returns "swiss" format:
-        handle = TogoWS.entry("uniprot", ["A1AG1_HUMAN","A1AG1_MOUSE"])
+        # Returns "swiss" format:
+        handle = TogoWS.entry("uniprot", ["A1AG1_HUMAN", "A1AG1_MOUSE"])
         record1, record2 = SeqIO.parse(handle, "swiss")
         handle.close()
 
@@ -364,8 +326,11 @@ class TogoEntry(unittest.TestCase):
         handle = TogoWS.entry("nucleotide", "6273291", "fasta")
         record = SeqIO.read(handle, "fasta")
         handle.close()
-        self.assertTrue("6273291" in record.id, record.id)
-        self.assertTrue("6273291" in record.name, record.name)
+        # NCBI is phasing out GI numbers, so no longer true:
+        # self.assertIn("6273291", record.id)
+        # self.assertIn("6273291", record.name)
+        self.assertIn("AF191665.1", record.id)
+        self.assertIn("AF191665.1", record.name)
         self.assertEqual(len(record), 902)
         self.assertEqual(seguid(record.seq), "bLhlq4mEFJOoS9PieOx4nhGnjAQ")
 
@@ -374,10 +339,12 @@ class TogoEntry(unittest.TestCase):
         handle = TogoWS.entry("protein", "16130152", "fasta")
         record = SeqIO.read(handle, "fasta")
         handle.close()
-        #Could use assertIn but requires Python 2.7+
-        self.assertTrue("16130152" in record.id, record.id)
-        self.assertTrue("16130152" in record.name, record.name)
-        self.assertTrue("porin protein" in record.description, record.description)
+        # NCBI is phasing out GI numbers, so no longer true:
+        # self.assertIn("16130152", record.id)
+        # self.assertIn("16130152", record.name)
+        self.assertIn("NP_416719.1", record.id)
+        self.assertIn("NP_416719.1", record.name)
+        self.assertIn("porin protein", record.description)
         self.assertEqual(len(record), 367)
         self.assertEqual(seguid(record.seq), "fCjcjMFeGIrilHAn6h+yju267lg")
 
@@ -427,25 +394,19 @@ class TogoSearch(unittest.TestCase):
     def test_pubmed_search_porin(self):
         """Bio.TogoWS.search_iter("pubmed", "human porin") etc
 
-        Count was 357 at time of writing, this was choosen to
+        Count was 357 at time of writing, this was chosen to
         be larger than the default chunk size for iteration,
         but still not too big to download the full list.
         """
         self.check("pubmed", "human porin", ["21189321", "21835183"])
 
-    def test_pdb_search_porin(self):
-        """Bio.TogoWS.search_iter("pdb", "porin") etc
-
-        Count was about 161 at time of writing.
-        """
-        self.check("pdb", "porin", ["2j1n", "2vqg", "3m8b", "2k0l"])
-
-    def test_embl_search_porin(self):
-        """Bio.TogoWS.search_iter("embl", "human pore", limit=200) etc
-
-        Count was about 297 at time of writing.
-        """
-        self.check("embl", "human pore", limit=200)
+# TogoWS search for PDBj currently unavailable
+#    def test_pdb_search_porin(self):
+#        """Bio.TogoWS.search_iter("pdb", "porin") etc
+#
+#        Count was about 161 at time of writing.
+#        """
+#        self.check("pdb", "porin", ["2j1n", "2vqg", "3m8b", "2k0l"])
 
     def test_uniprot_search_lung_cancer(self):
         """Bio.TogoWS.search_iter("uniprot", "terminal+lung+cancer", limit=150) etc
@@ -457,22 +418,25 @@ class TogoSearch(unittest.TestCase):
         """
         self.check("uniprot", "terminal+lung+cancer", limit=150)
 
-    def check(self, database, search_term, expected_matches=[], limit=None):
+    def check(self, database, search_term, expected_matches=(), limit=None):
         if expected_matches and limit:
             raise ValueError("Bad test - TogoWS makes no promises about order")
-        search_count = TogoWS.search_count(database, search_term)
+        try:
+            search_count = TogoWS.search_count(database, search_term)
+        except HTTPError as err:
+            raise ValueError("%s from %s" % (err, err.url))
         if expected_matches and search_count < len(expected_matches):
             raise ValueError("Only %i matches, expected at least %i"
                              % (search_count, len(expected_matches)))
         if search_count > 5000 and not limit:
-            print "%i results, skipping" % search_count
+            print("%i results, skipping" % search_count)
             return
         if limit:
             count = min(search_count, limit)
         else:
             count = search_count
 
-        #Iteration should find everything... unless a limit is used
+        # Iteration should find everything... unless a limit is used
         search_iter = list(TogoWS.search_iter(database, search_term, limit))
         self.assertEqual(count, len(search_iter))
         for match in expected_matches:
@@ -500,14 +464,15 @@ class TogoConvert(unittest.TestCase):
             new = SeqIO.read(TogoWS.convert(handle, "genbank", "fasta"), "fasta")
         self.assertEqual(str(old.seq), str(new.seq))
 
-    def test_genbank_to_embl(self):
-        """Conversion of GenBank to EMBL."""
-        filename = "GenBank/NC_005816.gb"
-        old = SeqIO.read(filename, "gb")
-        with open(filename) as handle:
-            new = SeqIO.read(TogoWS.convert(handle, "genbank", "embl"), "embl")
-        self.assertEqual(str(old.seq), str(new.seq))
+#    def test_genbank_to_embl(self):
+#        """Conversion of GenBank to EMBL."""
+#        filename = "GenBank/NC_005816.gb"
+#        old = SeqIO.read(filename, "gb")
+#        with open(filename) as handle:
+#            new = SeqIO.read(TogoWS.convert(handle, "genbank", "embl"), "embl")
+#        self.assertEqual(str(old.seq), str(new.seq))
+
 
 if __name__ == "__main__":
-    runner = unittest.TextTestRunner(verbosity = 2)
+    runner = unittest.TextTestRunner(verbosity=2)
     unittest.main(testRunner=runner)
